@@ -644,6 +644,10 @@ $router->rules('parse')->append('content', function ($uri)
 $router->rules('parse')->append('component', function ($uri)
 {
 	$component = $uri->getVar('option');
+	if (is_array($component))
+	{
+		$component = implode('', $component);
+	}
 	$segments  = explode('/', $uri->getPath());
 
 	if (!$component)
