@@ -84,23 +84,25 @@ $rows = $this->archive->entries($this->filters)
 <header id="content-header">
 	<h2><?php echo Lang::txt('COM_BLOG'); ?></h2>
 
-	<div id="content-header-extra">
-		<?php
-		$path  = 'index.php?option=' . $this->option . '&task=feed.rss';
-		$path .= ($this->filters['year']) ? '&year=' . $this->filters['year'] : '';
-		$path .= ($this->filters['month']) ? '&month=' . $this->filters['month'] : '';
+	<?php if ($this->config->get('feeds_enabled', 1)) : ?>
+		<div id="content-header-extra">
+			<?php
+			$path  = 'index.php?option=' . $this->option . '&task=feed.rss';
+			$path .= ($this->filters['year']) ? '&year=' . $this->filters['year'] : '';
+			$path .= ($this->filters['month']) ? '&month=' . $this->filters['month'] : '';
 
-		$feed = Route::url($path);
-		if (substr($feed, 0, 4) != 'http')
-		{
-			$live_site = rtrim(Request::base(),'/');
+			$feed = Route::url($path);
+			if (substr($feed, 0, 4) != 'http')
+			{
+				$live_site = rtrim(Request::base(),'/');
 
-			$feed = rtrim($live_site, '/') . '/' . ltrim($feed, '/');
-		}
-		$feed = str_replace('https:://','http://', $feed);
-		?>
-		<p><a class="icon-feed feed btn" href="<?php echo $feed; ?>"><?php echo Lang::txt('COM_BLOG_FEED'); ?></a></p>
-	</div>
+				$feed = rtrim($live_site, '/') . '/' . ltrim($feed, '/');
+			}
+			$feed = str_replace('https:://','http://', $feed);
+			?>
+			<p><a class="icon-feed feed btn" href="<?php echo $feed; ?>"><?php echo Lang::txt('COM_BLOG_FEED'); ?></a></p>
+		</div>
+	<?php endif; ?>
 </header>
 
 <section class="main section">
@@ -151,12 +153,12 @@ $rows = $this->archive->entries($this->filters)
 
 						if ($row->ended())
 						{
-							$cls .= ' expired';
+							//$cls .= ' expired';
 						}
 						?>
 						<li class="<?php echo $cls; ?>" id="e<?php echo $row->get('id'); ?>">
 							<article>
-								<h4 class="entry-title">
+								<h4 class="entry-title<?php if ($row->ended()) { echo ' icon-eye-close'; } ?>">
 									<a href="<?php echo Route::url($row->link()); ?>">
 										<?php echo $this->escape(stripslashes($row->get('title'))); ?>
 									</a>
@@ -208,10 +210,10 @@ $rows = $this->archive->entries($this->filters)
 									<?php } ?>
 									<?php if (User::get('id') == $row->get('created_by') || User::authorise('core.manage', $this->option)) { ?>
 										<dd class="entry-options">
-											<a class="edit" href="<?php echo Route::url($row->link('edit')); ?>" title="<?php echo Lang::txt('JACTION_EDIT'); ?>">
+											<a class="icon-edit edit" href="<?php echo Route::url($row->link('edit')); ?>" title="<?php echo Lang::txt('JACTION_EDIT'); ?>">
 												<?php echo Lang::txt('JACTION_EDIT'); ?>
 											</a>
-											<a class="delete" data-confirm="<?php echo Lang::txt('COM_BLOG_CONFIRM_DELETE'); ?>" href="<?php echo Route::url($row->link('delete')); ?>" title="<?php echo Lang::txt('JACTION_DELETE'); ?>">
+											<a class="icon-trash delete" data-confirm="<?php echo Lang::txt('COM_BLOG_CONFIRM_DELETE'); ?>" href="<?php echo Route::url($row->link('delete')); ?>" title="<?php echo Lang::txt('JACTION_DELETE'); ?>">
 												<?php echo Lang::txt('JACTION_DELETE'); ?>
 											</a>
 										</dd>
@@ -220,10 +222,10 @@ $rows = $this->archive->entries($this->filters)
 								<div class="entry-content">
 									<?php if ($this->config->get('cleanintro', 1)) { ?>
 										<p>
-											<?php echo \Hubzero\Utility\String::truncate(strip_tags($row->content), $this->config->get('introlength', 300)); ?>
+											<?php echo \Hubzero\Utility\Str::truncate(strip_tags($row->content), $this->config->get('introlength', 300)); ?>
 										</p>
 									<?php } else { ?>
-										<?php echo \Hubzero\Utility\String::truncate($row->content, $this->config->get('introlength', 300), array('html' => true)); ?>
+										<?php echo \Hubzero\Utility\Str::truncate($row->content, $this->config->get('introlength', 300), array('html' => true)); ?>
 									<?php } ?>
 								</div>
 							</article>
