@@ -133,7 +133,7 @@ foreach ($this->associations as $a)
 }
 
 //get the sub area we are trying to load
-$area = Request::getVar('area', 'about');
+$area = Request::getString('area', 'about');
 ?>
 
 <header id="content-header" class="half">
