@@ -173,7 +173,7 @@ class Posts extends AdminController
 		if (!is_object($row))
 		{
 			// Incoming
-			$id = Request::getVar('id', array(0));
+			$id = Request::getArray('id', array(0));
 
 			if (is_array($id))
 			{
@@ -207,7 +207,7 @@ class Posts extends AdminController
 		}
 
 		// Incoming
-		$fields = Request::getVar('fields', array(), 'post', 'none', 2);
+		$fields = Request::getArray('fields', array(), 'post', 'none', 2);
 
 		// Initiate model
 		$row = Post::oneOrNew($fields['id'])->set($fields);
@@ -220,7 +220,7 @@ class Posts extends AdminController
 		}
 
 		// Process tags
-		//$row->tag(trim(Request::getVar('tags', '')));
+		//$row->tag(trim(Request::getString('tags', '')));
 
 		Notify::success(Lang::txt('COM_COLLECTIONS_POST_SAVED'));
 
@@ -249,7 +249,7 @@ class Posts extends AdminController
 		}
 
 		// Incoming
-		$ids = Request::getVar('id', array());
+		$ids = Request::getArray('id', array());
 		$ids = (!is_array($ids) ? array($ids) : $ids);
 		$i = 0;
 
