@@ -639,7 +639,7 @@ class Article extends Relational implements \Hubzero\Search\Searchable
 	 *
 	 * @return  string
 	 */
-	public function searchNamespace()
+	public static function searchNamespace()
 	{
 		$searchNamespace = 'content';
 		return $searchNamespace;
@@ -652,7 +652,7 @@ class Article extends Relational implements \Hubzero\Search\Searchable
 	 */
 	public function searchId()
 	{
-		$searchId = $this->searchNamespace() . '-' . $this->id;
+		$searchId = self::searchNamespace() . '-' . $this->id;
 		return $searchId;
 	}
 
@@ -696,7 +696,7 @@ class Article extends Relational implements \Hubzero\Search\Searchable
 		$page->owner = $this->created_by;
 		$page->id = $this->searchId();
 		$page->title = $this->title;
-		$page->hubtype = $this->searchNamespace();
+		$page->hubtype = self::searchNamespace();
 		$page->description = \Hubzero\Utility\Sanitize::stripAll($this->introtext);
 		$page->fulltext = $this->introtext . ' ' . $this->fulltext;
 		return $page;
