@@ -44,7 +44,7 @@ function filter($res, $dd)
 
 	foreach ($header as $key => $val) {
 		if (count($data)>0) {
-			$field_type =  mysqli_fetch_field_direct($data, $field_offset);
+			$field_type = mysqli_fetch_field_direct($data, $field_offset)->type;
 		} else {
 			$field_type = 'string';
 		}
@@ -257,7 +257,7 @@ function filter($res, $dd)
 								$link_label = '<img class="dv_image lazy-load dv_img_preview ' . $missing . '" src="' . $small_img . '" data-preview-img="' . $medium_img . '" />';
 							}
 
-							$val[] = '<a title="' . $title . '" target="_blank" class="' . $missing . '" href="' . $link . '">' . $link_label . '</a> <br />';
+							$val[] = '<a title="' . $title . '" target="_blank" class="' . $missing . '" href="' . $link . '">' . $link_label . '</a>';
 						}
 						$val = implode('&nbsp;', $val);
 					} else {
@@ -357,7 +357,7 @@ function filter($res, $dd)
 
 						$path = $rec[$dd['cols'][$key]['gallery']];
 						$hash = get_dl_hash($path, 'gallery');
-						$gal_url = "/" . $com_name . '/gallery/' . $db_id . '/?hash=' . $hash;
+						$gal_url = "/" . $com_name . '/gallery/' . $hash;
 						$val = '<a target="_blank" class="dv_gallery_link" href="' . $gal_url . '"><img class="dv_image lazy-load dv_img_preview" src="' . $html_path . '/1x1.png" data-original="' . $small_img . '" data-preview-img="' . $medium_img . '" /></a>';
 					} else {
 						$val = '<a target="_blank" href="' . $original_img . '"><img class="dv_image lazy-load dv_img_preview" src="' . $html_path . '/1x1.png" data-original="' . $small_img . '" data-preview-img="' . $medium_img . '" /></a>';
@@ -504,7 +504,7 @@ function filter($res, $dd)
 					$append_to_url = isset($fv['append_to_url'])? $fv['append_to_url']: '';
 					$fv_data = array_key_exists($fv['data'], $rec)? $rec[$fv['data']]: $fv['data'];
 
-					$url = '/' . $com_name . '/' . $fv['task'] . '/' . $fv['db'] . '/' . $fv_data . '/' . $filter . $append_to_url;
+					$url = '/' . $com_name . '/' . $fv['task'] . '/' . $fv['db'] . '/' . $fv_data . '/' . $filter . $append_to_url . '#dv_top';
 					if ($fv_data != null) {
 						$val = '<a class="filtered_view" href="' . $url . '" title="Pre-filtered view">' . $val . '</a>';
 					}
@@ -524,7 +524,7 @@ function filter($res, $dd)
 					$append_to_url = isset($dd['cols'][$key]['custom_field_link']['append_to_url'])? $dd['cols'][$key]['custom_field_link']['append_to_url']: '';
 
 					$check = '<input type="checkbox" class="dv-custom-field-link" data-url-append=' . $append_to_url . ' data-col-id="dv-' . str_replace('.', '_', $key) . '" value="' . $v . '" style="float: right;" />';
-					$val = $check. '<a class="dv-custom-field-link" title="View filtered spreadsheet" target="_blank" href="/' . $com_name . '/view/' . $dd['db_id']['id'] . '/' . $dv . '/?custom_field=' . $field . '|' . $v . $append_to_url . '">' . $ll . '</a>';
+					$val = $check. '<a class="dv-custom-field-link" title="View filtered spreadsheet" target="_blank" href="/' . $com_name . '/view/' . $dd['db_id']['id'] . '/' . $dv . '/?custom_field=' . $field . '|' . $v . $append_to_url . '#dv_top">' . $ll . '</a>';
 				}
 
 				if (isset($dd['cols'][$key]['launch_view']) && !$null_val) {
@@ -536,7 +536,7 @@ function filter($res, $dd)
 					$filter = '?filter=' . implode('||', $filter);
 					$append_to_url = isset($fv['append_to_url'])? $fv['append_to_url']: '';
 
-					$val = '<a class="filtered_view" title="View filtered spreadsheet" target="_blank" href="/' . $com_name . '/view/' . $dd['db_id']['id'] . '/' . $fv['data'] . '/' . $fv['view'] . '/' . $filter . $append_to_url . '">' . $val . '</a>';
+					$val = '<a class="filtered_view" title="View filtered spreadsheet" target="_blank" href="/' . $com_name . '/view/' . $dd['db_id']['id'] . '/' . $fv['data'] . '/' . $fv['view'] . '/' . $filter . $append_to_url . '#dv_top">' . $val . '</a>';
 				}
 
 				if (isset($dd['cols'][$key]['abbr'])) {
