@@ -250,7 +250,7 @@ function query_gen(&$dd)
 		$col = $cols[$col_id];
 		$searchable = Request::getString('bSearchable_' . $i, 'false');
 		$fieldtype = Request::getString('fieldtype_' . $i, 'string');
-		$search_str = Request::getVar('sSearch_' . $i, '', 'default', null, 2);
+		$search_str = Request::getString('sSearch_' . $i, '');
 
 		if ($searchable === 'true' && $search_str !== '') {
 			if ($col['aggr']) {
@@ -264,7 +264,7 @@ function query_gen(&$dd)
 	}
 
 	// Filtered views
-	$filters = Request::getVar('filter', false, 'default', null, 2);
+	$filters = Request::getString('filter', false);
 	if ($filters !== false) {
 		$filters = explode('||', $filters);
 		foreach ($filters as $filter) {
@@ -496,7 +496,7 @@ function query_gen(&$dd)
 	$where_search = array();
 	$having_search = array();
 
-	$search_str = Request::getVar('sSearch', '', 'default', null, 2);
+	$search_str = Request::getString('sSearch', '');
 	if ($search_str != '') {
 		for ($i = 0; $i < count($cols_vis); $i++) {
 			$col_id = $cols_vis[$i];
@@ -632,9 +632,9 @@ function query_gen(&$dd)
 
 	// Limit
 	$limit = '';
-	$no_limit = Request::getVar('nolimit', false);
-	$limit_start = Request::getVar('iDisplayStart', false);
-	$limit_length = Request::getVar('iDisplayLength', $dv_conf['settings']['limit']);
+	$no_limit = Request::getString('nolimit', false);
+	$limit_start = Request::getString('iDisplayStart', false);
+	$limit_length = Request::getInt('iDisplayLength', $dv_conf['settings']['limit']);
 	if ($no_limit === false && $limit_start !== false && $limit_length != '-1') {
 		$limit = " LIMIT $limit_start, $limit_length";
 	} elseif ($no_limit === false && isset($dd['serverside']) && $dd['serverside']) {
