@@ -47,7 +47,7 @@ function get_dd($db_id)
 {
 	global $dv_conf;
 	$dd = false;
-	$dv_id = Request::getVar('dv');
+	$dv_id = Request::getString('dv');
 	$db_name = $db_id['name'];
 
 	$dv_conf['dd_json'] = "{$dv_conf['db_base_dir']}/$db_name/applications/dataviewer/datadefinitions";
@@ -131,14 +131,14 @@ function get_dd($db_id)
 
 function _dd_post($dd)
 {
-	$id = Request::getVar('id', false);
+	$id = Request::getString('id', false);
 
 	if ($id) {
 		$dd['where'][] = array('field'=>$dd['pk'], 'value'=>$id);
 		$dd['single'] = true;
 	}
 
-	$custom_field =  Request::getVar('custom_field', false);
+	$custom_field =  Request::getString('custom_field', false);
 	if ($custom_field) {
 		$custom_field = explode('|', $custom_field);
 		$dd['where'][] = array('field'=>$custom_field[0], 'value'=>$custom_field[1]);
@@ -146,7 +146,7 @@ function _dd_post($dd)
 	}
 
 	// Data for Custom Views
-	$custom_view = Request::getVar('custom_view', '');
+	$custom_view = Request::getString('custom_view', '');
 
 	if ($custom_view != '') {
 		$custom_view = explode(',', $custom_view);
@@ -201,4 +201,3 @@ function pathway($dd)
 
 	Pathway::append($dd['title'], $_SERVER['REQUEST_URI']);
 }
-?>
