@@ -53,7 +53,7 @@ use App;
 
 include_once dirname(dirname(__DIR__)) . DS . 'models' . DS . 'profile' . DS . 'field.php';
 include_once dirname(dirname(__DIR__)) . DS . 'helpers' . DS . 'utility.php';
-include_once Component::path('members') . '/models/registration.php';
+include_once \Component::path('members') . '/models/registration.php';
 
 /**
  * Manage site members
@@ -322,7 +322,7 @@ class Members extends AdminController
 		if (!$user)
 		{
 			// Incoming
-			$id = Request::getVar('id', array(0));
+			$id = Request::getArray('id', array(0));
 
 			// Get the single ID we're working with
 			if (is_array($id))
@@ -380,7 +380,7 @@ class Members extends AdminController
 		}
 
 		// Incoming profile edits
-		$fields = Request::getVar('fields', array(), 'post', 'none', 2);
+		$fields = Request::getArray('fields', array(), 'post');
 
 		// Load the profile
 		$user = Member::oneOrNew($fields['id']);
@@ -524,8 +524,8 @@ class Members extends AdminController
 		}
 
 		// Save profile data
-		$profile = Request::getVar('profile', array(), 'post', 'none', 2);
-		$access  = Request::getVar('profileaccess', array(), 'post', 'none', 2);
+		$profile = Request::getArray('profile', array(), 'post');
+		$access  = Request::getArray('profileaccess', array(), 'post');
 
 		foreach ($profile as $key => $data)
 		{
@@ -555,7 +555,7 @@ class Members extends AdminController
 		}
 
 		// Do we have a new pass?
-		$newpass = trim(Request::getVar('newpass', '', 'post'));
+		$newpass = trim(Request::getString('newpass', '', 'post'));
 
 		if ($newpass)
 		{
@@ -577,6 +577,17 @@ class Members extends AdminController
 			{
 				// Save password
 				\Hubzero\User\Password::changePassword($user->get('username'), $newpass);
+
+				// Remove login failures
+				$failures = \Hubzero\User\Log\Auth::all()
+					->whereEquals('username', $user->get('username'))
+					->whereEquals('status', 'failure')
+					->rows();
+
+				foreach ($failures as $failure)
+				{
+					$failure->destroy();
+				}
 			}
 		}
 
@@ -587,7 +598,7 @@ class Members extends AdminController
 			// Do we have shadow info to change?
 			$shadowMax     = Request::getInt('shadowMax', false, 'post');
 			$shadowWarning = Request::getInt('shadowWarning', false, 'post');
-			$shadowExpire  = Request::getVar('shadowExpire', '', 'post');
+			$shadowExpire  = Request::getString('shadowExpire', '', 'post');
 
 			if ($shadowMax || $shadowWarning || (!is_null($passinfo->get('shadowExpire')) && empty($shadowExpire)))
 			{
@@ -706,7 +717,7 @@ class Members extends AdminController
 		}
 
 		// Incoming
-		$ids = Request::getVar('id', array());
+		$ids = Request::getArray('id', array());
 		$ids = (!is_array($ids) ? array($ids) : $ids);
 
 		// Do we have any IDs?
@@ -778,7 +789,7 @@ class Members extends AdminController
 		$state = ($this->getTask() == 'confirm' ? 1 : 0);
 
 		// Incoming user ID
-		$ids = Request::getVar('id', array());
+		$ids = Request::getArray('id', array());
 		$ids = (!is_array($ids) ? array($ids) : $ids);
 
 		// Do we have an ID?
@@ -841,7 +852,7 @@ class Members extends AdminController
 		$state = ($this->getTask() == 'approve' ? 2 : 0);
 
 		// Incoming user ID
-		$ids = Request::getVar('id', array());
+		$ids = Request::getArray('id', array());
 		$ids = (!is_array($ids) ? array($ids) : $ids);
 
 		// Do we have an ID?
@@ -960,7 +971,7 @@ class Members extends AdminController
 		$state = ($this->getTask() == 'block' ? 1 : 0);
 
 		// Incoming user ID
-		$ids = Request::getVar('id', array());
+		$ids = Request::getArray('id', array());
 		$ids = (!is_array($ids) ? array($ids) : $ids);
 
 		// Do we have an ID?
@@ -1114,7 +1125,7 @@ class Members extends AdminController
 
 		$file  = DS . trim($this->config->get('webpath', '/site/members'), DS);
 		$file .= DS . Profile\Helper::niceidformat($member->get('uidNumber'));
-		$file .= DS . Request::getVar('image', $member->get('picture'));
+		$file .= DS . Request::getString('image', $member->get('picture'));
 
 		// Ensure the file exist
 		if (!file_exists(PATH_APP . DS . $file))
@@ -1318,7 +1329,7 @@ class Members extends AdminController
 		}
 
 		// Incoming data
-		$profile = json_decode(Request::getVar('profile', '{}', 'post', 'none', 2));
+		$profile = json_decode(Request::getString('profile', '{}', 'post'));
 
 		// Get the old schema
 		$fields = Field::all()
@@ -1513,7 +1524,7 @@ class Members extends AdminController
 		}
 
 		// Get the password
-		$pw = Request::getVar('password1', null, 'post');
+		$pw = Request::getString('password1', null, 'post');
 
 		// Validate the password
 		if (!empty($pw))
