@@ -40,7 +40,7 @@ $listOrder = $this->escape($this->filters['sort']);
 $listDirn  = $this->escape($this->filters['sort_Dir']);
 ?>
 <h2 class="modal-title"><?php echo Lang::txt('Users'); ?></h2>
-<form action="<?php echo Route::url('index.php?option=com_members&controllers=members&task=modal&tmpl=component&groups=' . Request::getVar('groups', '', 'default', 'BASE64') . '&excluded=' . Request::getVar('excluded', '', 'default', 'BASE64'));?>" method="post" name="adminForm" id="adminForm">
+<form action="<?php echo Route::url('index.php?option=com_members&controllers=members&task=modal&tmpl=component&groups=' . Request::getString('groups', '') . '&excluded=' . Request::getString('excluded', ''));?>" method="post" name="adminForm" id="adminForm">
 	<fieldset id="filter-bar" class="filter clearfix">
 		<div class="col width-70 fltlft">
 			<label for="filter_search"><?php echo Lang::txt('JSEARCH_FILTER'); ?></label>
