@@ -64,52 +64,19 @@ foreach ($this->fields as $field)
 <section class="main section">
 	<form action="<?php echo Route::url($base); ?>" method="get" class="section-inner">
 		<aside class="aside">
-			<?php /*<div class="container">
-				<h3><?php echo Lang::txt('COM_MEMBERS_BROWSE_SITE_MEMBERS'); ?></h3>
-				<p><?php echo Lang::txt('COM_MEMBERS_BROWSE_EXPLANATION'); ?></p>
-				<p><?php echo Lang::txt('COM_MEMBERS_BROWSE_SORTING_EXPLANATION'); ?></p>
-			</div><!-- / .container -->
-
-			<div class="container">
-				<h3><?php echo Lang::txt('COM_MEMBERS_BROWSE_MEMBER_STATS'); ?></h3>
-				<table>
-					<tbody>
-						<tr>
-							<th><?php echo Lang::txt('COM_MEMBERS_BROWSE_TOTAL_MEMBERS'); ?></th>
-							<td><span class="item-count"><?php echo $this->total_members; ?></span></td>
-						</tr>
-						<tr>
-							<th><?php echo Lang::txt('COM_MEMBERS_BROWSE_PRIVATE_PROFILES'); ?></th>
-							<td><span class="item-count"><?php echo $this->total_members - $this->total_public_members; ?></span></td>
-						</tr>
-						<tr>
-							<th><?php echo Lang::txt('COM_MEMBERS_BROWSE_NEW_PROFILES'); ?></th>
-							<td><span class="item-count"><?php echo $this->past_month_members; ?></span></td>
-						</tr>
-					</tbody>
-				</table>
-			</div><!-- / .container -->
-
-			<div class="container">
-				<h3><?php echo Lang::txt('COM_MEMBERS_BROWSE_LOOKING_FOR_GROUPS'); ?></h3>
-				<p>
-					<?php echo Lang::txt('COM_MEMBERS_BROWSE_GO_TO_GROUPS', Route::url('index.php?option=com_groups')); ?>
-				</p>
-			</div><!-- / .container -->*/ ?>
-
 			<div class="container">
 				<fieldset>
-					<legend><?php echo Lang::txt('Narrow results'); ?></legend>
+					<legend><?php echo Lang::txt('COM_MEMBERS_BROWSE_FILTERS'); ?></legend>
 
 					<div class="input-wrap">
 						<label for="filter-value-name">
 							<?php echo Lang::txt('COM_MEMBERS_SEARCH'); ?>
-							<input type="text" name="search" id="filter-value-name" value="<?php echo $this->escape($this->filters['search']); ?>" placeholder="<?php echo Lang::txt('Name or keyword...'); ?>" />
+							<input type="text" name="search" id="filter-value-name" value="<?php echo $this->escape($this->filters['search']); ?>" placeholder="<?php echo Lang::txt('COM_MEMBERS_SEARCH_PLACEHOLDER'); ?>" />
 						</label>
 					</div>
 
 					<fieldset class="filters">
-						<legend><?php echo Lang::txt('Filter'); ?></legend>
+						<legend><?php echo Lang::txt('COM_MEMBERS_BROWSE_FILTER'); ?></legend>
 
 						<?php foreach ($filters as $field) : ?>
 							<div class="input-wrap">
@@ -119,7 +86,14 @@ foreach ($this->fields as $field)
 								{
 									if ($q['field'] == $field->get('name'))
 									{
-										$value[] = $q['value'];
+										if (is_array($q['value']))
+										{
+											$value = array_merge($value, $q['value']);
+										}
+										else
+										{
+											$value[] = $q['value'];
+										}
 									}
 								}
 								?>
@@ -170,15 +144,15 @@ foreach ($this->fields as $field)
 					</fieldset><!-- / filters -->
 
 					<fieldset class="sorting">
-						<legend><?php echo Lang::txt('Sort'); ?></legend>
+						<legend><?php echo Lang::txt('COM_MEMBERS_BROWSE_SORT'); ?></legend>
 
 						<div class="input-wrap">
 							<label for="filter-value-sort">
-								<?php echo Lang::txt('Sort by'); ?>
+								<?php echo Lang::txt('COM_MEMBERS_BROWSE_SORT_BY'); ?>
 								<select name="sort" id="filter-value-sort">
 									<option value="name"><?php echo $this->escape('Name'); ?></option>
 									<?php foreach ($this->fields as $field) : ?>
-										<option value="<?php echo $this->escape($field->get('name')); ?>"><?php echo $this->escape($field->get('label')); ?></option>
+										<option value="<?php echo $this->escape($field->get('name')); ?>"<?php if ($field->get('name') == $this->filters['sort']) { echo ' selected="selected"'; } ?>><?php echo $this->escape($field->get('label')); ?></option>
 									<?php endforeach; ?>
 								</select>
 							</label>
@@ -186,16 +160,16 @@ foreach ($this->fields as $field)
 
 						<div class="input-wrap">
 							<label for="filter-value-sort-dir">
-								<?php echo Lang::txt('Direction'); ?>
+								<?php echo Lang::txt('COM_MEMBERS_BROWSE_SORT_DIR'); ?>
 								<select name="sort_Dir" id="filter-value-sort-dir">
-									<option value="asc"><?php echo $this->escape('Ascending (A-Z)'); ?></option>
-									<option value="desc"><?php echo $this->escape('Descending (Z-A)'); ?></option>
+									<option value="asc"<?php if ($this->filters['sort_Dir'] == 'asc') { echo ' selected="selected"'; } ?>><?php echo $this->escape(Lang::txt('COM_MEMBERS_BROWSE_SORT_DIR_ASC')); ?></option>
+									<option value="desc"<?php if ($this->filters['sort_Dir'] == 'desc') { echo ' selected="selected"'; } ?>><?php echo $this->escape(Lang::txt('COM_MEMBERS_BROWSE_SORT_DIR_DESC')); ?></option>
 								</select>
 							</label>
 						</div>
 					</fieldset><!-- / sort -->
 
-					<p><input class="btn" type="submit" value="<?php echo Lang::txt('Apply'); ?>" /></p>
+					<p><input class="btn" type="submit" value="<?php echo Lang::txt('COM_MEMBERS_APPLY'); ?>" /></p>
 				</fieldset>
 			</div>
 		</aside><!-- / .aside -->
@@ -207,10 +181,10 @@ foreach ($this->fields as $field)
 				foreach ($this->filters['q'] as $i => $q) :
 					if (is_array($q['value']))
 					{
-						$qs[$i] = '&';
+						$qs[$i] = array();
 						foreach ($q['value'] as $key => $val)
 						{
-							$qs[$i] .= 'q[' . $q['field'] . '][]=' . $val;
+							$qs[$i][] = '&q[' . $q['field'] . '][]=' . $val;
 						}
 					}
 					else if ($q['field'] == 'search')
@@ -230,14 +204,35 @@ foreach ($this->fields as $field)
 							<?php foreach ($this->filters['q'] as $i => $q) : ?>
 								<?php
 								$route = $base;
-								if (is_array($q['value']))
+								if (is_array($q['human_value']))
 								{
-									foreach ($q['value'] as $key => $val)
+									foreach ($q['human_value'] as $key => $val)
 									{
+										// @TODO: This is messy. Find a better way to do this.
+										$route = $base;
+										foreach ($qs as $k => $s)
+										{
+											if ($k == $i)
+											{
+												if (is_array($s))
+												{
+													foreach ($s as $kkey => $ss)
+													{
+														if ($kkey == $key)
+														{
+															continue;
+														}
+														$route .= (is_array($ss) ? implode('', $ss) : $ss);
+													}
+												}
+												continue;
+											}
+											$route .= (is_array($s) ? implode('', $s) : $s);
+										}
 										?>
 										<li>
 											<i><?php echo $q['human_field']; ?></i>: <?php echo $this->escape($val); ?>
-											<a href="<?php echo Route::url($route); ?>" class="icon-remove filters-x" title="<?php echo Lang::txt('Remove filter'); ?>"><?php echo Lang::txt('Remove filter'); ?></a>
+											<a href="<?php echo Route::url($route); ?>" class="icon-remove filters-x" title="<?php echo Lang::txt('COM_MEMBERS_BROWSE_FILTER_REMOVE'); ?>"><?php echo Lang::txt('COM_MEMBERS_BROWSE_FILTER_REMOVE'); ?></a>
 										</li>
 										<?php
 									}
@@ -250,12 +245,12 @@ foreach ($this->fields as $field)
 										{
 											continue;
 										}
-										$route .= $s;
+										$route .= (is_array($s) ? implode('', $s) : $s);
 									}
 									?>
 									<li>
 										<i><?php echo $q['human_field']; ?></i>: <?php echo $this->escape($q['human_value']); ?>
-										<a href="<?php echo Route::url($route); ?>" class="icon-remove filters-x" title="<?php echo Lang::txt('Remove filter'); ?>"><?php echo Lang::txt('Remove filter'); ?></a>
+										<a href="<?php echo Route::url($route); ?>" class="icon-remove filters-x" title="<?php echo Lang::txt('COM_MEMBERS_BROWSE_FILTER_REMOVE'); ?>"><?php echo Lang::txt('COM_MEMBERS_BROWSE_FILTER_REMOVE'); ?></a>
 									</li>
 								<?php } ?>
 							<?php endforeach; ?>
@@ -399,6 +394,9 @@ foreach ($this->fields as $field)
 									break;
 								}
 							}
+
+							$results = Event::trigger('members.onMemberProfile', array($row));
+							$extras = implode("\n", $results);
 							?>
 							<div class="result<?php echo ($cls) ? ' ' . $cls : ''; ?>">
 								<div class="result-body">
@@ -421,7 +419,7 @@ foreach ($this->fields as $field)
 											if ($val = $row->get($c->get('name'))) { ?>
 												<span class="result-details">
 													<span class="<?php echo $this->escape($c->get('name')); ?>">
-														<?php echo $this->escape(Hubzero\Utility\String::truncate(stripslashes($val), 60)); ?>
+														<?php echo $this->escape(Hubzero\Utility\Str::truncate(stripslashes($val), 60)); ?>
 													</span>
 												</span>
 											<?php } ?>
@@ -439,21 +437,23 @@ foreach ($this->fields as $field)
 												$val = (is_array($val) ? implode(', ', $val) : $val);
 											?>
 												<div class="result-snippet-<?php echo $this->escape($c->get('name')); ?>">
-													<?php echo $this->escape(Hubzero\Utility\String::truncate(strip_tags(stripslashes($val)), 150)); ?>
+													<?php echo $this->escape(Hubzero\Utility\Str::truncate(strip_tags(stripslashes($val)), 150)); ?>
 												</div>
 											<?php } ?>
 										<?php } ?>
 									</div>
-									<div class="result-options">
-										<?php if ($messageuser) { ?>
-											<a class="icon-email btn message-member" href="<?php echo Route::url('index.php?option=' . $this->option . '&id=' . User::get('id') . '&active=messages&task=new&to[]=' . $row->get('id')); ?>" title="<?php echo Lang::txt('COM_MEMBERS_BROWSE_SEND_MESSAGE_TO_TITLE', $this->escape($name)); ?>">
-												<?php echo Lang::txt('COM_MEMBERS_BROWSE_SEND_MESSAGE'); ?>
-											</a>
-										<?php } ?>
-										<a class="icon-user btn" href="<?php echo Route::url('index.php?option=' . $this->option . '&id=' . $row->get('id') . '&active=profile'); ?>" title="<?php echo Lang::txt('COM_MEMBERS_GO_TO_MEMBER_PROFILE', $this->escape($row->get('name'))); ?>">
-											<?php echo Lang::txt('COM_MEMBERS_PROFILE'); ?>
-										</a>
-									</div>
+									<?php if ($extras || $messageuser) { ?>
+										<div class="result-options">
+											<?php if ($messageuser) { ?>
+												<a class="icon-email btn message-member" href="<?php echo Route::url('index.php?option=' . $this->option . '&id=' . User::get('id') . '&active=messages&task=new&to[]=' . $row->get('id')); ?>" title="<?php echo Lang::txt('COM_MEMBERS_BROWSE_SEND_MESSAGE_TO_TITLE', $this->escape($name)); ?>">
+													<?php echo Lang::txt('COM_MEMBERS_BROWSE_SEND_MESSAGE'); ?>
+												</a>
+											<?php } ?>
+											<?php if ($extras) { ?>
+												<?php echo $extras; ?>
+											<?php } ?>
+										</div>
+									<?php } ?>
 									<?php if (!User::isGuest() && User::get('id') == $row->get('id')) { ?>
 										<span class="you">
 											<?php echo Lang::txt('COM_MEMBERS_BROWSE_YOUR_PROFILE'); ?>
@@ -491,7 +491,17 @@ foreach ($this->fields as $field)
 				{
 					foreach ($this->filters['q'] as $i => $q)
 					{
-						$pageNav->setAdditionalUrlParam('q[' . $q['field'] . ']', $q['value']);
+						if (is_array($q['value']))
+						{
+							foreach ($q['value'] as $val)
+							{
+								$pageNav->setAdditionalUrlParam('q[' . $q['field'] . '][]', $val);
+							}
+						}
+						else
+						{
+							$pageNav->setAdditionalUrlParam('q[' . $q['field'] . ']', $q['value']);
+						}
 					}
 				}
 				echo $pageNav;
