@@ -44,10 +44,10 @@ use Request;
 use Route;
 use Lang;
 
-require_once(dirname(dirname(__DIR__)) . DS . 'models' . DS . 'project.php');
-require_once(dirname(dirname(__DIR__)) . DS . 'models' . DS . 'orm' . DS . 'project.php');
-require_once(dirname(dirname(__DIR__)) . DS . 'models' . DS . 'orm' . DS . 'connection.php');
-require_once(dirname(dirname(__DIR__)) . DS . 'models' . DS . 'orm' . DS . 'provider.php');
+require_once dirname(dirname(__DIR__)) . DS . 'models' . DS . 'project.php';
+require_once dirname(dirname(__DIR__)) . DS . 'models' . DS . 'orm' . DS . 'project.php';
+require_once dirname(dirname(__DIR__)) . DS . 'models' . DS . 'orm' . DS . 'connection.php';
+require_once dirname(dirname(__DIR__)) . DS . 'models' . DS . 'orm' . DS . 'provider.php';
 
 /**
  * API controller for the projects files
@@ -70,7 +70,7 @@ class Filesv1_0 extends ApiController
 		Lang::load('com_projects') || Lang::load('com_projects', dirname(dirname(__DIR__)) . DS . 'site');
 
 		// Incoming
-		$id = Request::getVar('id', '');
+		$id = Request::getString('id', '');
 
 		$this->model = new Project($id);
 
@@ -94,7 +94,7 @@ class Filesv1_0 extends ApiController
 		}
 
 		//connection ID
-		$this->cid = Request::getVar('cid', '');
+		$this->cid = Request::getString('cid', '');
 
 		if ((in_array($this->_task, $connectionTasks)) && !$this->cid)
 		{
@@ -170,7 +170,8 @@ class Filesv1_0 extends ApiController
 
 		if ($this->cid) //connection specific listing
 		{
-			$dir = Entity::fromPath(Request::getVar('subdir', ''), $this->ormconn->adapter());
+			$dir = Entity::fromPath(Request::getString('subdir', ''), $this->ormconn->adapter());
+
 			try
 			{
 				$files = $dir->listContents();
@@ -185,8 +186,8 @@ class Filesv1_0 extends ApiController
 		else
 		{
 			$files = $this->model->repo()->filelist(array(
-				'subdir'           => Request::getVar('subdir', ''),
-				'filter'           => Request::getVar('filter', ''),
+				'subdir'           => Request::getString('subdir', ''),
+				'filter'           => Request::getString('filter', ''),
 				'limit'            => Request::getInt('limit', 0),
 				'start'            => Request::getInt('limitstart', 0),
 				'sortby'           => 'localpath',
@@ -240,7 +241,7 @@ class Filesv1_0 extends ApiController
 	public function getTask()
 	{
 		// Incoming
-		$files = Request::getVar('asset', array());
+		$files = Request::getArray('asset', array());
 
 		if (empty($files))
 		{
@@ -256,7 +257,7 @@ class Filesv1_0 extends ApiController
 			{
 				try
 				{
-					$entities[] = Entity::fromPath(Request::getVar('subdir', '', 'post') . DS . $file, $this->ormconn->adapter());
+					$entities[] = Entity::fromPath(Request::getString('subdir', '', 'post') . DS . $file, $this->ormconn->adapter());
 				}
 				catch (Exception $e)
 				{
@@ -268,7 +269,7 @@ class Filesv1_0 extends ApiController
 		else
 		{
 			$files = $this->model->repo()->filelist(array(
-				'subdir'           => Request::getVar('subdir', '', 'post'),
+				'subdir'           => Request::getString('subdir', '', 'post'),
 				'files'            => $files,
 				'showFullMetadata' => true,
 				'getParents'       => true,
@@ -310,7 +311,7 @@ class Filesv1_0 extends ApiController
 	 */
 	public function makedirectoryTask()
 	{
-		$directory = trim(Request::getVar('directory', ''));
+		$directory = trim(Request::getString('directory', ''));
 
 		if (empty($directory))
 		{
@@ -320,7 +321,8 @@ class Filesv1_0 extends ApiController
 
 		if ($this->cid) //connection specific operation
 		{
-			$entity  = Entity::fromPath(Request::getVar('subdir', '', 'post') . DS . $directory, $this->ormconn->adapter());
+			$entity  = Entity::fromPath(Request::getString('subdir', '', 'post') . DS . $directory, $this->ormconn->adapter());
+
 			if (!$entity->create())
 			{
 				$response->error = Lang::txt('Error creating directory');
@@ -334,7 +336,7 @@ class Filesv1_0 extends ApiController
 		{
 			// Set params
 			$params = array(
-				'subdir' => Request::getVar('subdir', '', 'post'),
+				'subdir' => Request::getString('subdir', '', 'post'),
 				'newDir' => urldecode($directory)
 			);
 
@@ -416,7 +418,8 @@ class Filesv1_0 extends ApiController
 
 			if ($this->cid) //connection specific operation
 			{
-				$entity  = Entity::fromPath(Request::getVar('subdir', '', 'post') . DS . $item, $this->ormconn->adapter());
+				$entity  = Entity::fromPath(Request::getString('subdir', '', 'post') . DS . $item, $this->ormconn->adapter());
+
 				try
 				{
 					if ($entity->delete())
@@ -434,7 +437,7 @@ class Filesv1_0 extends ApiController
 				$params = array(
 					'type'   => $type,
 					'item'   => $item,
-					'subdir' => Request::getVar('subdir', '', 'post')
+					'subdir' => Request::getString('subdir', '', 'post')
 				);
 
 				if ($this->model->repo()->deleteItem($params))
@@ -501,7 +504,7 @@ class Filesv1_0 extends ApiController
 		}
 
 		// Incoming
-		$target = trim(urldecode(Request::getVar('target', '')), DS);
+		$target = trim(urldecode(Request::getString('target', '')), DS);
 
 		$response = new stdClass;
 		$moved  = 0;
@@ -614,10 +617,10 @@ class Filesv1_0 extends ApiController
 
 		if ($this->cid)
 		{
-			$entity = Entity::fromPath(Request::getVar('subdir', '', 'post') . DS . Request::getVar('from', ''), $this->ormconn->adapter());
+			$entity = Entity::fromPath(Request::getString('subdir', '', 'post') . DS . Request::getString('from', ''), $this->ormconn->adapter());
 			try
 			{
-				if ($entity->rename(Request::getVar('to', '')))
+				if ($entity->rename(Request::getString('to', '')))
 				{
 					$response->success = 1;
 				}
@@ -631,10 +634,10 @@ class Filesv1_0 extends ApiController
 		{
 			// Set params
 			$params = array(
-				'subdir'  => Request::getVar('subdir', ''),
-				'from'    => Request::getVar('from', ''),
-				'to'      => Request::getVar('to', ''),
-				'type'    => Request::getVar('type', 'file')
+				'subdir'  => Request::getString('subdir', ''),
+				'from'    => Request::getString('from', ''),
+				'to'      => Request::getString('to', ''),
+				'type'    => Request::getString('type', 'file')
 			);
 
 			if ($this->model->repo()->rename($params))
@@ -697,7 +700,9 @@ class Filesv1_0 extends ApiController
 			if (is_uploaded_file($_FILES["file"]["tmp_name"]))
 			{
 				$updateType = 'uploaded';
-				$file  = Entity::fromPath(Request::getVar('subdir', '', 'post') . DS . $_FILES["file"]["name"], $this->ormconn->adapter());
+
+				$file  = Entity::fromPath(Request::getString('subdir', '', 'post') . DS . $_FILES["file"]["name"], $this->ormconn->adapter());
+
 				if ($file->exists())
 				{
 					$updateType = 'updated';
@@ -732,6 +737,227 @@ class Filesv1_0 extends ApiController
 		$this->send($response);
 	}
 
+	/**
+	 * Uploads file chunk(s) and combines them before adding the
+	 * final file to repository
+	 *
+	 * @apiMethod GET,POST
+	 * @apiUri    /projects/{id}/files/connections/{cid}/chunkedUpload
+	 * @apiParameter {
+	 * 		"name":        "id",
+	 * 		"description": "Project identifier (numeric ID or alias)",
+	 * 		"type":        "string",
+	 * 		"required":    true,
+	 * 		"default":     null
+	 * }
+	 * @apiParameter {
+	 * 		"name":        "cid",
+	 * 		"description": "Connection identifier (numeric ID)",
+	 * 		"type":        "string",
+	 * 		"required":    true,
+	 * 		"default":     null
+	 * }
+	 * @apiParameter {
+	 * 		"name":          "subdir",
+	 * 		"description":   "Directory path to upload to",
+	 * 		"type":          "string",
+	 * 		"required":      true,
+	 * 		"default":       "",
+	 * 		"allowedValues": ""
+	 * }
+	 * @apiParameter {
+	 * 		"name":          "flowFilename",
+	 * 		"description":   "Name of file being uploaded",
+	 * 		"type":          "string",
+	 * 		"required":      true,
+	 * 		"default":       "",
+	 * 		"allowedValues": ""
+	 * }
+	 * @apiParameter {
+	 * 		"name":          "flowIdentifier",
+	 * 		"description":   "Temporary file basename for chunk parts",
+	 * 		"type":          "string",
+	 * 		"required":      true,
+	 * 		"default":       "",
+	 * 		"allowedValues": ""
+	 * }
+	 * @apiParameter {
+	 * 		"name":          "flowTotalChunks",
+	 * 		"description":   "Total number of file chunks",
+	 * 		"type":          "integer",
+	 * 		"required":      true,
+	 * 		"default":       "",
+	 * 		"allowedValues": ""
+	 * }
+	 * @apiParameter {
+	 * 		"name":          "flowTotalSize",
+	 * 		"description":   "Total file size",
+	 * 		"type":          "integer",
+	 * 		"required":      true,
+	 * 		"default":       "",
+	 * 		"allowedValues": ""
+	 * }
+	 * @apiParameter {
+	 * 		"name":          "flowChunkNumber",
+	 * 		"description":   "Index of the chunk in the request",
+	 * 		"type":          "integer",
+	 * 		"required":      true,
+	 * 		"default":       "",
+	 * 		"allowedValues": ""
+	 * }
+	 * @apiParameter {
+	 * 		"name":          "flowChunkSize",
+	 * 		"description":   "Size of ths chunk in the request",
+	 * 		"type":          "integer",
+	 * 		"required":      true,
+	 * 		"default":       "",
+	 * 		"allowedValues": ""
+	 * }
+	 * @apiParameter {
+	 * 		"name":          "flowChunkHash",
+	 * 		"description":   "MD5 hash of the chunk in the request",
+	 * 		"type":          "string",
+	 * 		"required":      true,
+	 * 		"default":       "",
+	 * 		"allowedValues": ""
+	 * }
+	 *
+	 * @return  void
+	 */
+	public function chunkedUploadTask()
+	{
+
+		// Check if request is GET and the requested chunk exists or not.
+		if (Request::getMethod() === 'GET')
+		{
+			$flowIdentifier = Request::getString('flowIdentifier', '', 'GET');
+			$flowFilename = Request::getString('flowFilename', '', 'GET');
+			$flowChunkNumber = Request::getString('flowChunkNumber', '', 'GET');
+			$flowChunkHash = Request::getString('flowChunkHash', '', 'GET');
+			$subdir = Request::getString('subdir', '', 'GET');
+
+			$temp_dir  = sys_get_temp_dir() . DS . $this->model->get('id') . '_';
+			$temp_dir .= base64_encode($subdir) . '_' . $flowIdentifier;
+
+			$chunk_file = $temp_dir . DS . $flowFilename . '.part' . $flowChunkNumber;
+
+			if (file_exists($chunk_file))
+			{
+				// Also compare MD5 hash to make sure this is the same part as before
+				$hash = md5_file($chunk_file);
+				if (strcmp($hash, $flowChunkHash) === 0)
+				{
+					header("HTTP/1.0 200 OK");
+					exit;
+				}
+				else
+				{
+					unlink($chunk_file);
+					header("HTTP/1.0 204 Not Found");
+					exit;
+				}
+			}
+			else
+			{
+				header("HTTP/1.0 204 Not Found");
+				exit;
+			}
+		}
+
+		// Loop through files and move the chunks to a temporarily created directory
+		if (!empty($_FILES))
+		{
+			foreach ($_FILES as $file)
+			{
+				// check the error status
+				if ($file['error'] != 0)
+				{
+					continue;
+				}
+
+				// Init the destination file (format <filename.ext>.part<#chunk>)
+				// The file is stored in a temporary directory identified by the
+				// project ID, the base64 encoded destination and the filename
+				$flowIdentifier = Request::getString('flowIdentifier', '', 'POST');
+				$subdir = Request::getString('subdir', '', 'POST');
+				if (trim($flowIdentifier) != '')
+				{
+					$temp_dir  = sys_get_temp_dir() . DS . $this->model->get('id') . '_';
+					$temp_dir .= base64_encode($subdir) . '_' . $flowIdentifier;
+				}
+
+				$flowFilename = Request::getString('flowFilename', '', 'POST');
+				$flowChunkNumber = Request::getString('flowChunkNumber', '', 'POST');
+				$flowChunkSize = Request::getString('flowChunkSize', '', 'POST');
+				$flowTotalChunks = Request::getString('flowTotalChunks', '', 'POST');
+				$flowTotalSize = Request::getString('flowTotalSize', '', 'POST');
+
+				$dest_file = $temp_dir . DS . $flowFilename . '.part' . $flowChunkNumber;
+
+				// Create the temporary directory
+				if (!is_dir($temp_dir))
+				{
+					mkdir($temp_dir, 0777, true);
+				}
+
+				// Move the temporary file
+				if (!move_uploaded_file($file['tmp_name'], $dest_file))
+				{
+					header("HTTP/1.0 404 Error Uploading File");
+					exit;
+				}
+				else
+				{
+					// Check if all the parts present, and create the final destination file
+					$result = $this->createFileFromChunks(
+						$temp_dir,
+						$flowFilename,
+						$flowChunkSize,
+						$flowTotalSize,
+						$flowTotalChunks,
+						$subdir
+					);
+				}
+			}
+		}
+
+		if ($result)
+		{
+			$file  = Entity::fromPath($subdir . DS . $_FILES["file"]["name"], $this->ormconn->adapter());
+			if ($file->exists())
+			{
+				$updateType = 'updated';
+			}
+			$file->contents = file_get_contents($_FILES["file"]["tmp_name"]);
+			$file->size = (int) $_FILES["file"]["size"];
+			if ($file->save())
+			{
+				$parsedResults = array();
+
+				// Get metadata
+				$parsedResults[] = $this->ormconn->adapter()->getMetadata($file->getPath());
+
+				$response->results = $parsedResults;
+				$this->send($response);
+			}
+		}
+		else
+		{
+			//all chunks have been sent, but couldn't be recombined
+			if ($flowTotalChunks == $flowChunkNumber)
+			{
+				$response->error = "Error uploading file";
+				$this->send($response);
+			}
+			else
+			{
+				//not all chunks have been sent yet, just succeed
+				header("HTTP/1.0 200 OK");
+				exit;
+			}
+		}
+	}
+
 	/**
 	 * Download file or folder from project (non-default connection providers only)
 	 *
@@ -810,7 +1036,6 @@ class Filesv1_0 extends ApiController
 		{
 			exit;
 		}
-
 	}
 
 	/**
@@ -845,7 +1070,7 @@ class Filesv1_0 extends ApiController
 	public function saveTask()
 	{
 		// Incoming
-		$dataPath = Request::getVar('data_path', '', 'POST');
+		$dataPath = Request::getString('data_path', '', 'POST');
 
 		if (empty($dataPath))
 		{
@@ -859,7 +1084,7 @@ class Filesv1_0 extends ApiController
 				'dataPath'    => $dataPath,
 				'allowReplace'=> $this->_task == 'insert' ? false : true,
 				'update'      => $this->_task == 'insert' ? false : true,
-				'subdir'      => Request::getVar('subdir', '')
+				'subdir'      => Request::getString('subdir', '')
 			)
 		);
 
@@ -954,15 +1179,16 @@ class Filesv1_0 extends ApiController
 		$response = new stdClass;
 		$response->success = 0;
 
-		$files = Request::getVar('asset', array());
-		$fields   = Request::getVar('fields', array());
+		$files = Request::getArray('asset', array());
+		$fields   = Request::getArray('fields', array());
+
 		$response->metadata = array();
 
 		if (is_array($files))
 		{
 			foreach ($files as $file)
 			{
-				$entity = Entity::fromPath(Request::getVar('subdir', '', 'post') . DS . $file, $this->ormconn->adapter());
+				$entity = Entity::fromPath(Request::getString('subdir', '', 'post') . DS . $file, $this->ormconn->adapter());
 
 				if ($entity->exists())
 				{
@@ -1048,8 +1274,8 @@ class Filesv1_0 extends ApiController
 		$response = new stdClass;
 		$response->success = 0;
 
-		$files = Request::getVar('asset', array());
-		$metadata = Request::getVar('metadata', array());
+		$files = Request::getArray('asset', array());
+		$metadata = Request::getArray('metadata', array());
 
 		if (is_array($files))
 		{
@@ -1057,7 +1283,7 @@ class Filesv1_0 extends ApiController
 			{
 				foreach ($files as $file)
 				{
-					$entity = Entity::fromPath(Request::getVar('subdir', '', 'post') . DS . $file, $this->ormconn->adapter());
+					$entity = Entity::fromPath(Request::getString('subdir', '', 'post') . DS . $file, $this->ormconn->adapter());
 
 					if ($entity->exists())
 					{
@@ -1065,7 +1291,9 @@ class Filesv1_0 extends ApiController
 						{
 							$tmpoldmetadata = Event::trigger('metadata.onMetadataGet', [$entity]);
 							$oldmetadata = $this->_packMetadata($tmpoldmetadata[0]);
+
 							$error = Event::trigger('metadata.onMetadataSave', [$entity, array_merge($oldmetadata, $metadata)]);
+
 							if (empty($error))
 							{
 								$response->success = 1;
@@ -1175,8 +1403,8 @@ class Filesv1_0 extends ApiController
 	protected function _getCollection()
 	{
 		// Incoming
-		$files       = $this->_prune((array) Request::getVar('asset', []));
-		$directories = $this->_prune((array) Request::getVar('folder', []));
+		$files       = $this->_prune((array) Request::getArray('asset', []));
+		$directories = $this->_prune((array) Request::getArray('folder', []));
 		$collection  = new Collection;
 
 		$entities = array_merge($files, $directories);
@@ -1185,7 +1413,8 @@ class Filesv1_0 extends ApiController
 		{
 			foreach ($entities as $entity)
 			{
-				$path = trim(Request::getVar('subdir', ''), '/') . '/' . urldecode($entity);
+				$path = trim(Request::getString('subdir', ''), '/') . '/' . urldecode($entity);
+
 				$collection->add(Entity::fromPath($path, $this->ormconn->adapter()));
 			}
 		}
@@ -1224,8 +1453,8 @@ class Filesv1_0 extends ApiController
 	protected function _sortIncoming()
 	{
 		// Incoming
-		$checked = Request::getVar('asset', array());
-		$folders = Request::getVar('folder', array());
+		$checked = Request::getArray('asset', array());
+		$folders = Request::getArray('folder', array());
 
 		$combined = array();
 		if (!empty($checked) && is_array($checked))
@@ -1238,7 +1467,7 @@ class Filesv1_0 extends ApiController
 				}
 			}
 		}
-		elseif ($file = Request::getVar('asset', ''))
+		elseif ($file = Request::getString('asset', ''))
 		{
 			$combined[] = array('file' => urldecode($file));
 		}
@@ -1253,7 +1482,7 @@ class Filesv1_0 extends ApiController
 				}
 			}
 		}
-		elseif ($folder = Request::getVar('folder', ''))
+		elseif ($folder = Request::getString('folder', ''))
 		{
 			$combined[] = array('folder' => urldecode($folder));
 		}
@@ -1319,4 +1548,84 @@ class Filesv1_0 extends ApiController
 
 		$this->send($response);
 	}
+
+	/**
+	 * Check if all the chunks exist, and combine them into a final file
+	 *
+	 * @param   string  $temp_dir     The temporary directory holding all the parts of the file
+	 * @param   string  $fileName     The original file name
+	 * @param   string  $chunkSize    Each chunk size (in bytes)
+	 * @param   string  $totalSize    Original file size (in bytes)
+	 * @param   int     $total_files  The total number of chunks for this file
+	 * @param   int     $expand       Whether to automatically expand zip,tar,gz files
+	 * @return  array
+	 */
+	protected function createFileFromChunks($temp_dir, $fileName, $chunkSize, $totalSize, $total_files, $subdir)
+	{
+		// Count all the parts of this file
+		$total_files_on_server_size = 0;
+		$temp_total = 0;
+
+		$result = false;
+
+		foreach (scandir($temp_dir) as $file)
+		{
+			$temp_total = $total_files_on_server_size;
+			$tempfilesize = filesize($temp_dir . DS . $file);
+			$total_files_on_server_size = $temp_total + $tempfilesize;
+		}
+
+		// Check that all the parts are present
+		// If the Size of all the chunks on the server is equal to the size of the file uploaded.
+		if ($total_files_on_server_size >= $totalSize)
+		{
+			// Create a temporary file to combine all the chunks into
+			$fp = tmpfile();
+
+			for ($i = 1; $i <= $total_files; $i++)
+			{
+				fwrite($fp, file_get_contents($temp_dir . DS . $fileName . '.part' . $i));
+				unlink($temp_dir . DS . $fileName . '.part' . $i);
+			}
+
+			fseek($fp, 0);
+
+			$path = trim($subdir, DS) . DS . $fileName;
+
+			// Final destination file
+			$file = Entity::fromPath($path, $this->ormconn->adapter());
+
+			$file->contents = $fp;
+			$file->size     = $totalSize;
+
+			if ($file->save())
+			{
+				$result = true;
+			}
+			else
+			{
+				$result = false;
+			}
+
+			if (is_resource($file))
+			{
+				// Some (3rd party) adapters close the stream internally.
+				fclose($file);
+			}
+
+			// Rename the temporary directory (to avoid access from other
+			// Concurrent chunks uploads) and then delete it
+			if (rename($temp_dir, $temp_dir . '_UNUSED'))
+			{
+				Filesystem::deleteDirectory($temp_dir . '_UNUSED');
+			}
+			else
+			{
+				Filesystem::deleteDirectory($temp_dir);
+			}
+
+		}
+
+		return $result;
+	}
 }
