@@ -32,31 +32,35 @@
 
 namespace Components\Projects\Helpers;
 
-use Hubzero\Base\Object;
+use Hubzero\Base\Obj;
+use Component;
+use User;
+use Lang;
 
 /**
  * Projects Git helper class
  */
-class Nogit extends Object
+class Nogit extends Obj
 {
 	/**
 	 * User ID
 	 *
 	 * @var integer
 	 */
-	private $_uid 			= null;
+	private $_uid = null;
 
 	/**
 	 * Full path to Git repo
 	 *
 	 * @var string
 	 */
-	private $_path 		    = null;
+	private $_path = null;
 
 	/**
 	 * Constructor
 	 *
-	 * @return     void
+	 * @param   string  $path
+	 * @return  void
 	 */
 	public function __construct($path = null)
 	{
@@ -73,11 +77,10 @@ class Nogit extends Object
 	/**
 	 * Init Git repository
 	 *
-	 * @param      string	$path	Repo path
-	 *
-	 * @return     string
+	 * @param   string  $path  Repo path
+	 * @return  string
 	 */
-	public function iniGit( $path = null)
+	public function iniGit($path = null)
 	{
 		if (!$path)
 		{
@@ -97,11 +100,10 @@ class Nogit extends Object
 	/**
 	 * Make a call
 	 *
-	 * @param      string	$call
-	 *
-	 * @return     array to be parsed
+	 * @param   string  $call
+	 * @return  array   to be parsed
 	 */
-	public function call ($call = '')
+	public function call($call = '')
 	{
 		if (!$this->_path || !is_dir($this->_path) || !$call)
 		{
@@ -118,9 +120,8 @@ class Nogit extends Object
 	/**
 	 * Exec call
 	 *
-	 * @param      string	$call
-	 *
-	 * @return     array to be parsed
+	 * @param   string  $call
+	 * @return  array   to be parsed
 	 */
 	protected function _exec($call = '')
 	{
@@ -139,10 +140,9 @@ class Nogit extends Object
 	/**
 	 * Get file content
 	 *
-	 * @param      string  	$file		file path
-	 * @param      string  	$target		Output content to path
-	 *
-	 * @return     void
+	 * @param   string  $file    file path
+	 * @param   string  $target  Output content to path
+	 * @return  bool
 	 */
 	public function getContent($file = '', $target = '')
 	{
@@ -158,12 +158,11 @@ class Nogit extends Object
 	/**
 	 * Parse response
 	 *
-	 * @param      array  	$out		Array of data to parse
-	 * @param      string  	$return
-	 *
-	 * @return     mixed
+	 * @param   array  	$out     Array of data to parse
+	 * @param   string  $return
+	 * @return  mixed
 	 */
-	public function parseLog ($out = array(), $return = 'date')
+	public function parseLog($out = array(), $return = 'date')
 	{
 		return '';
 	}
@@ -174,18 +173,18 @@ class Nogit extends Object
 	 * @param   string  $subdir  Local directory path
 	 * @return  array
 	 */
-	public function getFiles($subdir = '', $showAll = false, $recursive = false)
+	public function getFiles($subdir = '', $recursive = false)
 	{
 		// Make sure subdir has a trailing slash
 		$subdir = (!empty($subdir)) ? trim($subdir, DS) . DS : '';
 		// Get list of all files
-		if ($showAll)
+		if ($recursive)
 		{
-			$out = $this->call("find -not -path -'.'" . escapeshellarg($subdir));
+			$out = $this->call("find ./" . escapeshellarg($subdir) . " -mindepth 1 -name '.git*' -prune -o -printf '%P\n' -not -path -'.'");
 		}
 		else
 		{
-			$out = $this->call("ls -A1 " . escapeshellarg("./" . $subdir));
+			$out = $this->call("find ./" . escapeshellarg($subdir) . " -mindepth 1 -maxdepth 1 -name '.git*' -prune -o -printf '%P\n' -not -path -'.'");
 		}
 
 		return (empty($out)) ? array() : $out;
@@ -203,17 +202,21 @@ class Nogit extends Object
 		$subdir = (!empty($subdir)) ? trim($subdir, DS) . DS : '';
 
 		// Get list of the directories
-		$out = $this->call("find -type d -not -path -'.'");
+		$out = $this->call("find -name '.git*' -prune -o -type d -not -path -'.' -printf '%P\n'");
 		return (empty($out) || substr($out[0], 0, 5) == 'fatal') ? array() : $out;
 	}
 
 	/**
 	 * Get changes for sync
 	 *
-	 * @return     array
+	 * @param   string  $localPath
+	 * @param   string  $synced
+	 * @param   string  $localDir
+	 * @param   array   $localRenames
+	 * @param   array   $connections
+	 * @return  array
 	 */
-	public function getChanges ($localPath = '', $synced = '',
-		$localDir = '', &$localRenames, $connections)
+	public function getChanges($localPath = '', $synced = '', $localDir = '', &$localRenames, $connections)
 	{
 		//Stub for compatibility
 		return array();
@@ -222,12 +225,12 @@ class Nogit extends Object
 	/**
 	 * Make Git recognize empty folder
 	 *
-	 * @param      string	$path
-	 * @param      string	$dir
-	 *
-	 * @return     array to be parsed
+	 * @param   string  $dir
+	 * @param   bool    $commit
+	 * @param   string  $commitMsg
+	 * @return  bool
 	 */
-	public function makeEmptyFolder ( $dir = '', $commit = true, $commitMsg = '' )
+	public function makeEmptyFolder($dir = '', $commit = true, $commitMsg = '')
 	{
 		// Check for repo
 		if (!$this->_path || !is_dir($this->_path))
@@ -239,7 +242,7 @@ class Nogit extends Object
 		chdir($this->_path);
 
 		// Git add
-		$this->gitAdd($dir, $commitMsg );
+		$this->gitAdd($dir, $commitMsg);
 
 		if ($commit == false)
 		{
@@ -258,12 +261,11 @@ class Nogit extends Object
 	/**
 	 * Filter ASCII
 	 *
-	 * @param      array	$out
-	 * @param      boolean	$diff	Format as diff?
-	 * @param      boolean	$color	Color changes?
-	 * @param      int		$max	Max number of lines
-	 *
-	 * @return     string
+	 * @param   array    $out
+	 * @param   boolean  $diff   Format as diff?
+	 * @param   boolean  $color  Color changes?
+	 * @param   int      $max    Max number of lines
+	 * @return  string
 	 */
 	public static function filterASCII($out = array(), $diff = false, $color = false, $max = 200)
 	{
@@ -340,19 +342,18 @@ class Nogit extends Object
 	/**
 	 * Determine if last change was a rename
 	 *
-	 * @param      string	$file		file path
-	 * @param      string	$hash		Git hash
-	 * @param      string	$since
-	 *
-	 * @return     array to be parsed
+	 * @param   string  $file   file path
+	 * @param   string  $hash   Git hash
+	 * @param   string  $since
+	 * @return  array   to be parsed
 	 */
-	public function getRename ($file = '', $hash = '', $since = '' )
+	public function getRename($file = '', $hash = '', $since = '')
 	{
 		$renames = $this->gitLog($file, '', 'rename');
 		$rename = '';
 
 		$hashes = $this->getLocalFileHistory($file);
-		$new	= $this->getLocalFileHistory($file, '', $since);
+		$new    = $this->getLocalFileHistory($file, '', $since);
 		$fetch  = 1;
 
 		if (count($renames) > 0)
@@ -388,13 +389,12 @@ class Nogit extends Object
 	/**
 	 * Show commit log detail
 	 *
-	 * @param      string  	$file		file path
-	 * @param      string  	$hash		Git hash
-	 * @param      string  	$return
-	 *
-	 * @return     string
+	 * @param   string  $file    file path
+	 * @param   string  $hash    Git hash
+	 * @param   string  $return
+	 * @return  string
 	 */
-	public function gitLog ($file = '', $hash = '', $return = 'date')
+	public function gitLog($file = '', $hash = '', $return = 'date')
 	{
 		if (!$this->_path || !is_dir($this->_path))
 		{
