@@ -35,12 +35,12 @@ use Google_Service_Drive_Permission;
 use Google_Service_Drive_DriveFile;
 use Google_Service_Drive_ParentReference;
 use Google_Http_MediaFileUpload;
-use Hubzero\Base\Object;
+use Hubzero\Base\Obj;
 
 /**
  * Projects Google Drive helper class
  */
-class Google extends Object
+class Google extends Obj
 {
 	/**
 	 * Load file metadata
@@ -226,7 +226,8 @@ class Google extends Object
 		// Are we converting to Google format?
 		if ($convert == true)
 		{
-			$fparams['convert'] = true;
+			//$fparams['convert'] = true;
+			$file->setMimeType(self::mimetypeToGoogle($mimeType));
 
 			// OCR conversion
 			if ($mimeType == 'application/pdf' || $mimeType == 'image/png' || $mimeType == 'image/jpeg' || $mimeType == 'image/gif')
@@ -483,7 +484,7 @@ class Google extends Object
 	public static function deleteAllParents($apiService, $id = 0)
 	{
 		// Check for what we need
-		if (!$apiService || !$id)
+		if (!$apiService || !isset($apiService->parents) || !$id)
 		{
 			return false;
 		}
@@ -707,7 +708,7 @@ class Google extends Object
 					{
 						$title = Filesystem::clean($doc['title']);
 
-						// Get file extention
+						// Get file extension
 						$ext = Filesystem::extension($title);
 
 						if ($converted)
@@ -893,14 +894,44 @@ class Google extends Object
 		$q .= " and mimeType = 'application/vnd.google-apps.folder' ";
 
 		$parameters = array(
-			'q' => $q,
-			'fields' => 'items(id,title,labels/trashed,parents/id)'
+			'q' => $q//,
+			//'fields' => 'items(id,title,labels/trashed,parents/id)'
 		);
 
 		// Get a list of files in remote folder
 		try
 		{
 			$data = $apiService->files->listFiles($parameters);
+
+			$items = $items = $data->getFiles();
+			if (!empty($items))
+			{
+				$lpath = $path ? $path : '';
+				foreach ($items as $item)
+				{
+					// Skip deleted items
+					if ($item->getTrashed())
+					{
+						continue;
+					}
+
+					$title  = Filesystem::cleanPath($item->getName());
+					$fpath  = $lpath ? $lpath . DS . $title : $title;
+					$status = $item->getTrashed() ? 'D' : 'A';
+
+					$remoteFolders[$fpath] = array(
+						'remoteid' => $item->getId(),
+						'status'   => $status,
+						'rParent'  => self::getParentID($item->getParents())
+					);
+
+					// Recurse
+					self::getFolders($apiService, $item->getId(), $remoteFolders, $fpath);
+				}
+			}
+
+			/*
+			$data = $apiService->files->listFiles($parameters);
 			if (!empty($data['items']))
 			{
 				$lpath = $path ? $path : '';
@@ -926,6 +957,7 @@ class Google extends Object
 					self::getFolders($apiService, $item['id'], $remoteFolders, $fpath);
 				}
 			}
+			*/
 		}
 		catch (Exception $e)
 		{
@@ -945,8 +977,14 @@ class Google extends Object
 	{
 		if (!empty($parents))
 		{
+			if (is_object($parents[0]))
+			{
+				return $parents[0]->getId();
+			}
+
 			return $parents[0]['id'];
 		}
+
 		return null;
 	}
 
@@ -976,14 +1014,140 @@ class Google extends Object
 		$q = "'" . $folderID . "' in parents";
 
 		$parameters = array(
-			'q' => $q,
-			'fields' => 'items(id,title,mimeType,downloadUrl,md5Checksum,labels,fileSize,thumbnailLink,modifiedDate,parents/id,originalFilename,lastModifyingUserName,ownerNames)'
+			'q' => $q//,
+			//'fields' => 'items(id,title,mimeType,downloadUrl,md5Checksum,labels,fileSize,thumbnailLink,modifiedDate,parents/id,originalFilename,lastModifyingUserName,ownerNames)'
 		);
 
 		// Get a list of files in remote folder
 		try
 		{
 			$data = $apiService->files->listFiles($parameters);
+			$items = $data->getFiles();
+			if (!empty($items))
+			{
+				$lpath = $path ? $path : '';
+				foreach ($items as $item)
+				{
+					$time   = strtotime($item->getModifiedTime());
+					$status = $item->getTrashed() ? 'D' : 'A';
+					$skip   = 0;
+
+					// Check against modified date
+					$changed = (strtotime(date("c", strtotime($item->getModifiedTime()))) - strtotime($since));
+					if ($since && $changed <= 0 && $item->getTrashed() != 1)
+					{
+						$skip = 1;
+					}
+
+					$converted = preg_match("/google-apps/", $item->getMimeType()) && !preg_match("/.folder/", $item->getMimeType()) ? 1 : 0;
+					$url       = $item->getWebContentLink() ? $item->getWebContentLink() : $item->getWebViewLink();
+					//$url = $url ?: 'https://www.googleapis.com/drive/v3/files/' . $item->getId() . '?alt=media';
+					$original  = $item->getOriginalFilename();
+					$thumb     = $item->getThumbnailLink();
+
+					$author    = null; /*isset($item['lastModifyingUserName'])
+											? utf8_encode($item['lastModifyingUserName'])
+											: utf8_encode($item['ownerNames'][0]);*/
+
+					if (!preg_match("/.folder/", $item->getMimeType()))
+					{
+						$title = Filesystem::clean($item->getName());
+
+						if ($converted)
+						{
+							$ext = self::getGoogleConversionFormat($item->getMimeType(), false, true);
+							if ($ext)
+							{
+								$title = $title . '.' . $ext;
+							}
+						}
+
+						$type = 'file';
+					}
+					else
+					{
+						$title = Filesystem::cleanPath($item->getName());
+						$type = 'folder';
+					}
+
+					$fpath = $lpath ? $lpath . DS . $title : $title;
+
+					$synced      = isset($conIds[$item->getId()]) ? $conIds[$item->getId()]['synced'] : null;
+					$md5Checksum = $item->getMd5Checksum();
+					$fileSize    = $item->getSize();
+
+					/// Make sure path is not already used (Google allows files with same name in same dir, Git doesn't)
+					$fpath = self::buildDuplicatePath($item->getId(), $fpath, $item->getMimeType(), $connections, $remotes, $duplicates);
+
+					// Detect a rename or move
+					$rename = '';
+					if (isset($conIds[$item->getId()]))
+					{
+						$oFilePath = $conIds[$item->getId()]['path'];
+						$oDirPath  = $conIds[$item->getId()]['dirpath'];
+						$nDirPath  = dirname($fpath) == '.' ? '' : dirname($fpath);
+						$nFilePath = $fpath;
+
+						if ($oDirPath != $nDirPath && $oFilePath != $nFilePath)
+						{
+							$status = 'W';
+							$rename = $oFilePath;
+						}
+						elseif ($oFilePath != $nFilePath)
+						{
+							$status = 'R';
+							$rename = $oFilePath;
+						}
+					}
+
+					// Check that file was last synced after modified date
+					// (important to pick up failed updates)
+					if (isset($conIds[$item->getId()]))
+					{
+						if ($conIds[$item->getId()]['modified'] < gmdate('Y-m-d H:i:s', $time))
+						{
+							$skip = 0;
+						}
+					}
+					elseif ($status == 'A')
+					{
+						// Never skip new files
+						$skip = 0;
+					}
+
+					if (!$skip)
+					{
+						$remotes[$fpath] = array(
+							'status'     => $status,
+							'time'       => $time,
+							'modified'   => gmdate('Y-m-d H:i:s', $time),
+							'type'       => $type,
+							'local_path' => $fpath,
+							'remoteid'   => $item->getId(),
+							'title'      => $item->getName(),
+							'converted'  => $converted,
+							'rParent'    => self::getParentID($item->getParents()),
+							'url'        => $url,
+							'original'   => $original,
+							'author'     => $author,
+							'synced'     => $synced,
+							'md5'        => $md5Checksum,
+							'mimeType'   => $item->getMimeType(),
+							'thumb'      => $thumb,
+							'rename'     => $rename,
+							'fileSize'   => $fileSize
+						);
+					}
+
+					if (preg_match("/.folder/", $item->getMimeType()))
+					{
+						// Recurse
+						$remotes = self::getFolderContent($apiService, $item->getId(), $remotes, $fpath, $since, $connections, $duplicates);
+					}
+				}
+			}
+
+			/*$data = $apiService->files->listFiles($parameters);
 
 			if (!empty($data['items']))
 			{
@@ -1106,7 +1270,7 @@ class Google extends Object
 						$remotes = self::getFolderContent($apiService, $item['id'], $remotes, $fpath, $since, $connections, $duplicates);
 					}
 				}
-			}
+			}*/
 		}
 		catch (Exception $e)
 		{
@@ -1211,7 +1375,7 @@ class Google extends Object
 	 */
 	public static function getImportFilename($name = '', $importExt = '')
 	{
-		// Get file extention
+		// Get file extension
 		$parts = explode('.', $name);
 		$ext   = count($parts) > 1 ? array_pop($parts) : '';
 
@@ -1234,7 +1398,7 @@ class Google extends Object
 	{
 		$ext = '';
 
-		// Get file extention
+		// Get file extension
 		$parts = explode('.', $file);
 		$ext   = count($parts) > 1 ? array_pop($parts) : '';
 
@@ -1346,6 +1510,57 @@ class Google extends Object
 		return $ext;
 	}
 
+	/**
+	 * Mimetype to Google mimetype conversion
+	 *
+	 * @param   string  $mimeType
+	 * @return  string
+	 */
+	public static function mimetypeToGoogle($mimeType = '')
+	{
+		$ext = $mimeType;
+
+		switch ($mimeType)
+		{
+			// Documents
+			case 'text/plain':
+			case 'application/rtf':
+			case 'application/msword':
+			case 'application/x-rtf':
+			case 'text/rtf':
+			case 'text/richtext':
+			case 'application/doc':
+			case 'application/x-soffice':
+			case 'application/vnd.openxmlformats-officedocument.wordprocessingml.document':
+				$ext = 'application/vnd.google-apps.document';
+				break;
+
+			// Slides
+			case 'application/vnd.ms-powerpoint':
+			case 'application/vnd.openxmlformats-officedocument.presentationml.presentation':
+			case 'application/vnd.oasis.opendocument.presentation':
+				$ext = 'application/vnd.google-apps.presentation';
+				break;
+
+			// Spreadsheets
+			case 'text/x-comma-separated-values':
+			case 'application/vnd.ms-excel':
+			case 'application/vnd.openxmlformats-officedocument.spreadsheetml.sheet':
+			case 'application/vnd.oasis.opendocument.spreadsheet':
+			case 'application/x-vnd.oasis.opendocument.spreadsheet':
+				$ext = 'application/vnd.google-apps.spreadsheet';
+				break;
+
+			case 'image/png':
+			case 'image/jpeg':
+			case 'image/svg+xml':
+				$ext = 'application/vnd.google-apps.drawing';
+				break;
+		}
+
+		return $ext;
+	}
+
 	/**
 	 * Get default Google export format
 	 *
