@@ -32,12 +32,12 @@
 
 namespace Components\Projects\Models\Adapters;
 
-use Hubzero\Base\Object;
 use Components\Projects\Models;
 use Components\Projects\Helpers;
+use Component;
+use Filesystem;
 
-require_once PATH_CORE . DS . 'components' . DS . 'com_projects' . DS . 'helpers' . DS . 'nogithelper.php';
-
+require_once dirname(dirname(__DIR__)) . DS . 'helpers' . DS . 'nogithelper.php';
 
 /**
  * Projects Git adapter class
