@@ -38,6 +38,7 @@ require_once dirname(__DIR__) . DS . 'tables' . DS . 'comment.php';
 require_once dirname(__DIR__) . DS . 'tables' . DS . 'owner.php';
 require_once dirname(__DIR__) . DS . 'tables' . DS . 'type.php';
 require_once dirname(__DIR__) . DS . 'tables' . DS . 'todo.php';
+require_once Component::path('com_projects') . '/models/orm/owner.php';
 
 require_once dirname(__DIR__) . DS . 'helpers' . DS . 'html.php';
 
@@ -1575,6 +1576,10 @@ class Project extends Model
 				}
 			}
 		}
+		elseif (is_file($path . DS . 'master.png') && $size != 'original')
+		{
+			$src = $path . DS . 'master.png';
+		}
 		else
 		{
 			// Get the picture if set
