@@ -42,11 +42,11 @@ use Request;
 use Plugin;
 use Lang;
 
-require_once(dirname(__DIR__) . DS . 'tables' . DS . 'repo.php');
-require_once(dirname(__DIR__) . DS . 'helpers' . DS . 'githelper.php');
-require_once(dirname(__DIR__) . DS . 'helpers' . DS . 'nogithelper.php');
-require_once(__DIR__ . DS . 'file.php');
-require_once(__DIR__ . DS . 'adapter.php');
+require_once dirname(__DIR__) . DS . 'tables' . DS . 'repo.php';
+require_once dirname(__DIR__) . DS . 'helpers' . DS . 'githelper.php';
+require_once dirname(__DIR__) . DS . 'helpers' . DS . 'nogithelper.php';
+require_once __DIR__ . DS . 'file.php';
+require_once __DIR__ . DS . 'adapter.php';
 
 /**
  * Project Repository model
@@ -205,7 +205,7 @@ class Repo extends Obj
 				{
 					throw new \InvalidArgumentException(Lang::txt('Invalid engine of "%s"', $engine));
 				}
-				include_once($path);
+				include_once $path;
 			}
 
 			$this->_adapter = new $cls($this->get('path'), $this->get('remote'));
@@ -1018,7 +1018,7 @@ class Repo extends Obj
 		else
 		{
 			// Regular upload
-			$upload = Request::getVar('upload', '', 'files', 'array');
+			$upload = Request::getArray('upload', '', 'files');
 
 			if (empty($upload['name']) or $upload['name'][0] == '')
 			{
