@@ -46,30 +46,30 @@ class Authors extends Base
 	/**
 	 * Block name
 	 *
-	 * @var		string
+	 * @var  string
 	 */
-	protected $_name 			= 'authors';
+	protected $_name = 'authors';
 
 	/**
 	 * Parent block name
 	 *
-	 * @var		string
+	 * @var  string
 	 */
-	protected $_parentname 		= 'authors';
+	protected $_parentname = 'authors';
 
 	/**
 	 * Default manifest
 	 *
-	 * @var		string
+	 * @var  string
 	 */
-	protected $_manifest 		= null;
+	protected $_manifest = null;
 
 	/**
 	 * Numeric block ID
 	 *
-	 * @var		integer
+	 * @var  integer
 	 */
-	protected $_blockId 		= 0;
+	protected $_blockId = 0;
 
 	/**
 	 * Display block content
@@ -80,7 +80,7 @@ class Authors extends Base
 	 * @param   integer  $blockId
 	 * @return  string   HTML
 	 */
-	public function display( $pub = null, $manifest = null, $viewname = 'edit', $blockId = 0)
+	public function display($pub = null, $manifest = null, $viewname = 'edit', $blockId = 0)
 	{
 		// Set block manifest
 		if ($this->_manifest === null)
@@ -96,8 +96,8 @@ class Authors extends Base
 			// Output HTML
 			$view = new \Hubzero\Component\View(
 				array(
-					'name'		=> 'curation',
-					'layout'	=> 'block'
+					'name'   => 'curation',
+					'layout' => 'block'
 				)
 			);
 		}
@@ -108,25 +108,25 @@ class Authors extends Base
 			// Output HTML
 			$view = new \Hubzero\Plugin\View(
 				array(
-					'folder'	=> 'projects',
-					'element'	=> 'publications',
-					'name'		=> $name,
-					'layout'	=> 'wrapper'
+					'folder'  => 'projects',
+					'element' => 'publications',
+					'name'    => $name,
+					'layout'  => 'wrapper'
 				)
 			);
 		}
 
-		$view->manifest 	= $this->_manifest;
-		$view->content 		= self::buildContent( $pub, $viewname );
-		$view->pub			= $pub;
-		$view->active		= $this->_name;
-		$view->step			= $blockId;
+		$view->manifest     = $this->_manifest;
+		$view->content      = self::buildContent($pub, $viewname);
+		$view->pub          = $pub;
+		$view->active       = $this->_name;
+		$view->step         = $blockId;
 		$showGroupOwner     = isset($this->_manifest->params->group_owner) ? $this->_manifest->params->group_owner : '';
 		$view->showControls = $showGroupOwner ? 4 : 2;
 
 		if ($this->getError())
 		{
-			$view->setError( $this->getError() );
+			$view->setError($this->getError());
 		}
 		return $view->loadTemplate();
 	}
@@ -141,7 +141,7 @@ class Authors extends Base
 	 * @param   integer  $elementId
 	 * @return  string   HTML
 	 */
-	public function save( $manifest = null, $blockId = 0, $pub = null, $actor = 0, $elementId = 0)
+	public function save($manifest = null, $blockId = 0, $pub = null, $actor = 0, $elementId = 0)
 	{
 		// Set block manifest
 		if ($this->_manifest === null)
@@ -155,7 +155,7 @@ class Authors extends Base
 			return false;
 		}
 
-		$selections = Request::getVar( 'selecteditems', '');
+		$selections = Request::getString('selecteditems', '');
 		$toAttach = explode(',', $selections);
 		$added = 0;
 
@@ -177,9 +177,9 @@ class Authors extends Base
 				// Restore deleted author
 				if ($pAuthor->status == 2 || $pAuthor->status == 0)
 				{
-					$pAuthor->status 		= 1;
-					$pAuthor->modified 		= Date::toSql();
-					$pAuthor->modified_by 	= $actor;
+					$pAuthor->status      = 1;
+					$pAuthor->modified    = Date::toSql();
+					$pAuthor->modified_by = $actor;
 
 					if ($pAuthor->updateAssociationByOwner())
 					{
@@ -193,17 +193,17 @@ class Authors extends Base
 				$profile = $pAuthor->getProfileInfoByOwner($owner);
 				$invited = $profile->invited_name ? $profile->invited_name : $profile->invited_email;
 
-				$pAuthor->project_owner_id 			= $owner;
-				$pAuthor->publication_version_id 	= $pub->version_id;
-				$pAuthor->user_id 					= $profile->uidNumber ? $profile->uidNumber : 0;
-				$pAuthor->ordering 					= $order;
-				$pAuthor->status 					= 1;
-				$pAuthor->organization 				= $profile->organization ? $profile->organization : '';
-				$pAuthor->name 						= $profile && $profile->name ? $profile->name : $invited;
-				$pAuthor->firstName 				= $profile->givenName ? $profile->givenName : '';
-				$pAuthor->lastName 					= $profile->surname ? $profile->surname : '';
-				$pAuthor->created 					= Date::toSql();
-				$pAuthor->created_by 				= $actor;
+				$pAuthor->project_owner_id       = $owner;
+				$pAuthor->publication_version_id = $pub->version_id;
+				$pAuthor->user_id                = $profile->uidNumber ? $profile->uidNumber : 0;
+				$pAuthor->ordering               = $order;
+				$pAuthor->status                 = 1;
+				$pAuthor->organization           = $profile->organization ? $profile->organization : '';
+				$pAuthor->name                   = $profile && $profile->name ? $profile->name : $invited;
+				$pAuthor->firstName              = $profile->givenName ? $profile->givenName : '';
+				$pAuthor->lastName               = $profile->surname ? $profile->surname : '';
+				$pAuthor->created                = Date::toSql();
+				$pAuthor->created_by             = $actor;
 
 				if (!$pAuthor->createAssociation())
 				{
@@ -224,7 +224,7 @@ class Authors extends Base
 
 		if ($added)
 		{
-			$this->set('_message', Lang::txt('Author selection saved') );
+			$this->set('_message', Lang::txt('Author selection saved'));
 		}
 
 		// Save group owner
@@ -242,10 +242,10 @@ class Authors extends Base
 	 * @param   object  $pub
 	 * @return  void
 	 */
-	public function saveGroupOwner( $pub )
+	public function saveGroupOwner($pub)
 	{
 		// Incoming
-		$group_owner = Request::getInt( 'group_owner', 0);
+		$group_owner = Request::getInt('group_owner', 0);
 
 		$saveGroupOwner = isset($this->_manifest->params->group_owner) ? $this->_manifest->params->group_owner : '';
 
@@ -265,14 +265,14 @@ class Authors extends Base
 	 * @param   object   $newVersion
 	 * @return  boolean
 	 */
-	public function transferData( $manifest, $pub, $oldVersion, $newVersion )
+	public function transferData($manifest, $pub, $oldVersion, $newVersion)
 	{
 		// Get authors
 		if (!isset($pub->_authors))
 		{
-			$pAuthors 			= new \Components\Publications\Tables\Author( $this->_parent->_db );
-			$pub->_authors 		= $pAuthors->getAuthors($pub->version_id);
-			$pub->_submitter 	= $pAuthors->getSubmitter($pub->version_id, $pub->created_by);
+			$pAuthors = new \Components\Publications\Tables\Author($this->_parent->_db);
+			$pub->_authors   = $pAuthors->getAuthors($pub->version_id);
+			$pub->_submitter = $pAuthors->getSubmitter($pub->version_id, $pub->created_by);
 		}
 
 		if (!$pub->_authors)
@@ -282,18 +282,18 @@ class Authors extends Base
 
 		foreach ($pub->_authors as $author)
 		{
-			$pAuthor 							= new \Components\Publications\Tables\Author( $this->_parent->_db );
-			$pAuthor->user_id 					= $author->user_id;
-			$pAuthor->ordering 					= $author->ordering;
-			$pAuthor->credit 					= $author->credit;
-			$pAuthor->role 						= $author->role;
-			$pAuthor->status 					= $author->status;
-			$pAuthor->organization 				= $author->organization;
-			$pAuthor->name 						= $author->name;
-			$pAuthor->project_owner_id 			= $author->project_owner_id;
-			$pAuthor->publication_version_id 	= $newVersion->id;
-			$pAuthor->created 					= Date::toSql();
-			$pAuthor->created_by 				= User::get('id');
+			$pAuthor = new \Components\Publications\Tables\Author($this->_parent->_db);
+			$pAuthor->user_id                = $author->user_id;
+			$pAuthor->ordering               = $author->ordering;
+			$pAuthor->credit                 = $author->credit;
+			$pAuthor->role                   = $author->role;
+			$pAuthor->status                 = $author->status;
+			$pAuthor->organization           = $author->organization;
+			$pAuthor->name                   = $author->name;
+			$pAuthor->project_owner_id       = $author->project_owner_id;
+			$pAuthor->publication_version_id = $newVersion->id;
+			$pAuthor->created                = Date::toSql();
+			$pAuthor->created_by             = User::get('id');
 			if (!$pAuthor->createAssociation())
 			{
 				continue;
@@ -313,7 +313,7 @@ class Authors extends Base
 	 * @param   integer  $elementId
 	 * @return  string   HTML
 	 */
-	public function reorder( $manifest = null, $blockId = 0, $pub = null, $actor = 0, $elementId = 0)
+	public function reorder($manifest = null, $blockId = 0, $pub = null, $actor = 0, $elementId = 0)
 	{
 		// Set block manifest
 		if ($this->_manifest === null)
@@ -322,7 +322,7 @@ class Authors extends Base
 		}
 
 		// Incoming
-		$list = Request::getVar( 'list', '' );
+		$list = Request::getString('list', '');
 		$authors = explode("-", $list);
 
 		$o = 1;
@@ -333,7 +333,7 @@ class Authors extends Base
 				continue;
 			}
 
-			$pAuthor = new \Components\Publications\Tables\Author( $this->_parent->_db );
+			$pAuthor = new \Components\Publications\Tables\Author($this->_parent->_db);
 			if ($pAuthor->load($id))
 			{
 				$pAuthor->ordering = $o;
@@ -343,7 +343,7 @@ class Authors extends Base
 			}
 		}
 
-		$this->set('_message', Lang::txt('New author order saved') );
+		$this->set('_message', Lang::txt('New author order saved'));
 
 		return true;
 	}
@@ -358,44 +358,43 @@ class Authors extends Base
 	 * @param   integer  $elementId
 	 * @return  void
 	 */
-	public function addItem ($manifest, $blockId, $pub, $actor = 0, $elementId = 0)
+	public function addItem($manifest, $blockId, $pub, $actor = 0, $elementId = 0)
 	{
 		$config = Component::params('com_publications');
 
 		$emailConfig = $config->get('email');
-		$email 		= Request::getVar( 'email', '', 'post' );
-		$firstName 	= trim(Request::getVar( 'firstName', '', 'post' ));
-		$lastName 	= trim(Request::getVar( 'lastName', '', 'post' ));
-		$org 		= trim(Request::getVar( 'organization', '', 'post' ));
-		$credit 	= trim(Request::getVar( 'credit', '', 'post' ));
-		$uid 		= trim(Request::getInt( 'uid', 0, 'post' ));
+		$email      = Request::getString('email', '', 'post');
+		$firstName  = trim(Request::getString('firstName', '', 'post'));
+		$lastName   = trim(Request::getString('lastName', '', 'post'));
+		$org        = trim(Request::getString('organization', '', 'post'));
+		$credit     = trim(Request::getString('credit', '', 'post'));
+		$uid        = trim(Request::getInt('uid', 0, 'post'));
 
-		$regex 		= '/^([a-zA-Z0-9_.-])+@([a-zA-Z0-9_-])+(.[a-zA-Z0-9_-]+)+/';
-		$email 		= preg_match($regex, $email) ? $email : '';
-		$name 		= $firstName . ' ' . $lastName;
+		$regex      = '/^([a-zA-Z0-9_.-])+@([a-zA-Z0-9_-])+(.[a-zA-Z0-9_-]+)+/';
+		$email      = preg_match($regex, $email) ? $email : '';
+		$name       = $firstName . ' ' . $lastName;
 
 		$sendInvite = 0;
-		$exists 	= 0;
-		$code 		= \Components\Projects\Helpers\Html::generateCode();
+		$exists     = 0;
+		$code       = \Components\Projects\Helpers\Html::generateCode();
 
 		if (!$firstName || !$lastName)
 		{
-			$this->setError( Lang::txt('PLG_PROJECTS_PUBLICATIONS_ERROR_MISSING_REQUIRED'));
+			$this->setError(Lang::txt('PLG_PROJECTS_PUBLICATIONS_ERROR_MISSING_REQUIRED'));
 			return false;
 		}
 
 		// Load classes
-		$objO = new \Components\Projects\Tables\Owner( $this->_parent->_db );
+		$objO = new \Components\Projects\Tables\Owner($this->_parent->_db);
 
 		// Instantiate a new registration object
-		include_once(PATH_CORE . DS . 'components' . DS
-			. 'com_members' . DS . 'models' . DS . 'registration.php');
+		include_once \Component::path('com_members') . DS . 'models' . DS . 'registration.php';
 		$xregistration = new \Components\Members\Models\Registration();
 
 		// Do we have a registered user with this email?
 		if ($email && !$uid)
 		{
-			$uid = $xregistration->getEmailId( $email );
+			$uid = $xregistration->getEmailId($email);
 
 			// Check that profile exists
 			if ($uid)
@@ -409,16 +408,16 @@ class Authors extends Base
 		$owner = null;
 		if ($uid)
 		{
-			$owner = $objO->getOwnerId( $pub->_project->get('id'), $uid );
+			$owner = $objO->getOwnerId($pub->_project->get('id'), $uid);
 		}
 		elseif ($email)
 		{
-			$owner = $objO->checkInvited( $pub->_project->get('id'), $email );
+			$owner = $objO->checkInvited($pub->_project->get('id'), $email);
 		}
 		elseif (trim($name))
 		{
 			// Check by invite name
-			$owner = $objO->checkInvitedByName( $pub->_project->get('id'), trim($name));
+			$owner = $objO->checkInvitedByName($pub->_project->get('id'), trim($name));
 		}
 
 		if ($owner && $objO->load($owner))
@@ -427,20 +426,20 @@ class Authors extends Base
 			{
 				$sendInvite = 1;
 			}
-			$objO->status 			= $objO->userid ? 1 : 0;
-			$objO->invited_name 	= $objO->userid ? $objO->invited_name : $name;
-			$objO->invited_email 	= $objO->userid ? $objO->invited_email : $email;
+			$objO->status        = $objO->userid ? 1 : 0;
+			$objO->invited_name  = $objO->userid ? $objO->invited_name : $name;
+			$objO->invited_email = $objO->userid ? $objO->invited_email : $email;
 			$objO->store();
 		}
 		elseif ($email || trim($name))
 		{
-			$objO = new \Components\Projects\Tables\Owner( $this->_parent->_db );
+			$objO = new \Components\Projects\Tables\Owner($this->_parent->_db);
 
-			$objO->projectid 	 = $pub->_project->get('id');
-			$objO->userid 		 = $uid;
-			$objO->status 		 = $uid ? 1 : 0;
-			$objO->added 		 = Date::toSql();
-			$objO->role 		 = 2;
+			$objO->projectid     = $pub->_project->get('id');
+			$objO->userid        = $uid;
+			$objO->status        = $uid ? 1 : 0;
+			$objO->added         = Date::toSql();
+			$objO->role          = \Components\Projects\Models\Orm\Owner::ROLE_INVITEE;
 			$objO->invited_email = $email;
 			$objO->invited_name  = $name;
 
@@ -451,46 +450,46 @@ class Authors extends Base
 
 			$objO->store();
 
-			$owner 				 = $objO->id;
-			$sendInvite 		 = ($email || $uid) ? 1 : 0;
+			$owner      = $objO->id;
+			$sendInvite = ($email || $uid) ? 1 : 0;
 		}
 
 		// Now we do need owner record
 		if (!$owner)
 		{
-			$this->setError( Lang::txt('PLG_PROJECTS_PUBLICATIONS_AUTHORS_ERROR_SAVING_AUTHOR_INFO'));
+			$this->setError(Lang::txt('PLG_PROJECTS_PUBLICATIONS_AUTHORS_ERROR_SAVING_AUTHOR_INFO'));
 			return false;
 		}
 
 		// Get author information
-		$pAuthor = new \Components\Publications\Tables\Author( $this->_parent->_db );
+		$pAuthor = new \Components\Publications\Tables\Author($this->_parent->_db);
 
-		if ($pAuthor->loadAssociationByOwner( $owner, $pub->version_id ))
+		if ($pAuthor->loadAssociationByOwner($owner, $pub->version_id))
 		{
-			$pAuthor->modified 		= Date::toSql();
-			$pAuthor->modified_by 	= $actor;
+			$pAuthor->modified    = Date::toSql();
+			$pAuthor->modified_by = $actor;
 			$exists = 1;
 		}
 		else
 		{
-			$pAuthor->created 				 = Date::toSql();
-			$pAuthor->created_by 			 = $actor;
+			$pAuthor->created                = Date::toSql();
+			$pAuthor->created_by             = $actor;
 			$pAuthor->publication_version_id = $pub->version_id;
-			$pAuthor->project_owner_id 		 = $owner;
+			$pAuthor->project_owner_id       = $owner;
 			$pAuthor->user_id                = intval($uid);
 			$pAuthor->ordering 	             = $pAuthor->getLastOrder($pub->version_id) + 1;
-			$pAuthor->role 				 	 = '';
+			$pAuthor->role                   = '';
 		}
 
-		$pAuthor->status 		= 1;
-		$pAuthor->name   		= $name;
-		$pAuthor->firstName 	= $firstName;
-		$pAuthor->lastName  	= $lastName;
-		$pAuthor->organization  = $org;
+		$pAuthor->status       = 1;
+		$pAuthor->name         = $name;
+		$pAuthor->firstName    = $firstName;
+		$pAuthor->lastName     = $lastName;
+		$pAuthor->organization = $org;
 
 		if (!$pAuthor->store())
 		{
-			$this->setError( Lang::txt('PLG_PROJECTS_PUBLICATIONS_AUTHORS_ERROR_SAVING_AUTHOR_INFO'));
+			$this->setError(Lang::txt('PLG_PROJECTS_PUBLICATIONS_AUTHORS_ERROR_SAVING_AUTHOR_INFO'));
 			return false;
 		}
 
@@ -504,7 +503,7 @@ class Authors extends Base
 			$project = new \Components\Projects\Models\Project($pub->_project->get('id'));
 
 			// Load component language file
-			Lang::load('com_projects') || Lang::load('com_projects', PATH_CORE . DS . 'components' . DS . 'com_projects' . DS . 'site');
+			Lang::load('com_projects') || Lang::load('com_projects', \Component::path('com_projects') . DS . 'site');
 
 			// Plugin params
 			$plugin_params = array(
@@ -517,7 +516,7 @@ class Authors extends Base
 			);
 
 			// Send invite
-			$output = Event::trigger( 'projects.sendInviteEmail', $plugin_params);
+			$output = Event::trigger('projects.sendInviteEmail', $plugin_params);
 			$result = json_decode($output[0]);
 		}
 
@@ -525,7 +524,7 @@ class Authors extends Base
 			? Lang::txt('Author already in team, updated author information')
 			: Lang::txt('New author added');
 
-		$this->set('_message', $message );
+		$this->set('_message', $message);
 		return true;
 	}
 
@@ -540,24 +539,23 @@ class Authors extends Base
 	 * @param   integer  $aid
 	 * @return  void
 	 */
-	public function saveItem ($manifest, $blockId, $pub, $actor = 0, $elementId = 0, $aid = 0)
+	public function saveItem($manifest, $blockId, $pub, $actor = 0, $elementId = 0, $aid = 0)
 	{
-		$aid = $aid ? $aid : Request::getInt( 'aid', 0 );
+		$aid = $aid ? $aid : Request::getInt('aid', 0);
 
 		// Load classes
-		$row  = new \Components\Publications\Tables\Author( $this->_parent->_db );
-		$objO = new \Components\Projects\Tables\Owner( $this->_parent->_db );
+		$row  = new \Components\Publications\Tables\Author($this->_parent->_db);
+		$objO = new \Components\Projects\Tables\Owner($this->_parent->_db);
 
 		// We need attachment record
 		if (!$aid || !$row->load($aid) || $row->publication_version_id != $pub->version_id)
 		{
-			$this->setError( Lang::txt('PLG_PROJECTS_PUBLICATIONS_CONTENT_ERROR_LOAD_AUTHOR'));
+			$this->setError(Lang::txt('PLG_PROJECTS_PUBLICATIONS_CONTENT_ERROR_LOAD_AUTHOR'));
 			return false;
 		}
 
 		// Instantiate a new registration object
-		include_once(PATH_CORE . DS . 'components' . DS . 'com_members'
-			. DS . 'models' . DS . 'registration.php');
+		include_once \Component::path('com_members') . DS . 'models' . DS . 'registration.php';
 		$xregistration = new \Components\Members\Models\Registration();
 
 		// Get current owners
@@ -566,31 +564,31 @@ class Authors extends Base
 		$config = Component::params('com_publications');
 
 		$emailConfig = $config->get('email');
-		$email 		= Request::getVar( 'email', '', 'post' );
-		$firstName 	= Request::getVar( 'firstName', '', 'post' );
-		$lastName 	= Request::getVar( 'lastName', '', 'post' );
-		$org 		= Request::getVar( 'organization', '', 'post' );
-		$credit 	= Request::getVar( 'credit', '', 'post' );
+		$email      = Request::getString('email', '', 'post');
+		$firstName  = Request::getString('firstName', '', 'post');
+		$lastName   = Request::getString('lastName', '', 'post');
+		$org        = Request::getString('organization', '', 'post');
+		$credit     = Request::getString('credit', '', 'post');
 		$sendInvite = 0;
-		$code 		= \Components\Projects\Helpers\Html::generateCode();
-		$uid 		= Request::getInt( 'uid', 0, 'post' );
+		$code       = \Components\Projects\Helpers\Html::generateCode();
+		$uid        = Request::getInt('uid', 0, 'post');
 
 		$regex = '/^([a-zA-Z0-9_.-])+@([a-zA-Z0-9_-])+(.[a-zA-Z0-9_-]+)+/';
 		$email = preg_match($regex, $email) ? $email : '';
 
 		if (!$firstName || !$lastName)
 		{
-			$this->setError( Lang::txt('PLG_PROJECTS_PUBLICATIONS_ERROR_MISSING_REQUIRED'));
+			$this->setError(Lang::txt('PLG_PROJECTS_PUBLICATIONS_ERROR_MISSING_REQUIRED'));
 			return false;
 		}
 
 		$row->organization  = $org;
-		$row->firstName 	= $firstName;
-		$row->lastName 		= $lastName;
-		$row->name 	 		= $row->firstName . ' ' . $row->lastName;
-		$row->credit 		= $credit;
-		$row->modified_by 	= $actor;
-		$row->modified 		= Date::toSql();
+		$row->firstName     = $firstName;
+		$row->lastName      = $lastName;
+		$row->name          = $row->firstName . ' ' . $row->lastName;
+		$row->credit        = $credit;
+		$row->modified_by   = $actor;
+		$row->modified      = Date::toSql();
 
 		// Check that profile exists
 		if ($uid)
@@ -603,7 +601,7 @@ class Authors extends Base
 		if ($uid && !$row->user_id)
 		{
 			// Do we have an owner with this user id?
-			$owner = $objO->getOwnerId( $pub->_project->get('id'), $uid );
+			$owner = $objO->getOwnerId($pub->_project->get('id'), $uid);
 
 			if ($owner)
 			{
@@ -625,21 +623,21 @@ class Authors extends Base
 
 		if ($row->store())
 		{
-			$this->set('_message', Lang::txt('Author record saved') );
+			$this->set('_message', Lang::txt('Author record saved'));
 
 			// Reflect the update in curation record
 			$this->_parent->set('_update', 1);
 		}
 		else
 		{
-			$this->setError( Lang::txt('PLG_PROJECTS_PUBLICATIONS_AUTHORS_ERROR_SAVING_AUTHOR_INFO'));
+			$this->setError(Lang::txt('PLG_PROJECTS_PUBLICATIONS_AUTHORS_ERROR_SAVING_AUTHOR_INFO'));
 			return false;
 		}
 
 		// Update project owner (invited)
 		if ($email && !$row->user_id && $objO->load($row->project_owner_id))
 		{
-			$invitee = $objO->checkInvited( $pub->_project->get('id'), $email );
+			$invitee = $objO->checkInvited($pub->_project->get('id'), $email);
 
 			// Do we have a registered user with this email?
 			$user = $xregistration->getEmailId($email);
@@ -656,7 +654,7 @@ class Authors extends Base
 			{
 				$objO->invited_email = $email;
 				$objO->invited_name  = $row->name;
-				$objO->userid 		 = $row->user_id;
+				$objO->userid        = $row->user_id;
 				$objO->invited_code  = $code;
 				$objO->store();
 				$sendInvite = 1;
@@ -680,7 +678,7 @@ class Authors extends Base
 			);
 
 			// Send invite
-			$output = Event::trigger( 'projects.sendInviteEmail', $plugin_params);
+			$output = Event::trigger('projects.sendInviteEmail', $plugin_params);
 			$result = json_decode($output[0]);
 		}
 
@@ -698,24 +696,24 @@ class Authors extends Base
 	 * @param   integer  $aid
 	 * @return  boolean
 	 */
-	public function deleteItem ($manifest, $blockId, $pub, $actor = 0, $elementId = 0, $aid = 0)
+	public function deleteItem($manifest, $blockId, $pub, $actor = 0, $elementId = 0, $aid = 0)
 	{
-		$aid = $aid ? $aid : Request::getInt( 'aid', 0 );
+		$aid = $aid ? $aid : Request::getInt('aid', 0);
 
 		// Load classes
-		$row  = new \Components\Publications\Tables\Author( $this->_parent->_db );
-		$objO = new \Components\Projects\Tables\Owner( $this->_parent->_db );
+		$row  = new \Components\Publications\Tables\Author($this->_parent->_db);
+		$objO = new \Components\Projects\Tables\Owner($this->_parent->_db);
 
 		// We need attachment record
 		if (!$aid || !$row->load($aid) || $row->publication_version_id != $pub->version_id)
 		{
-			$this->setError( Lang::txt('PLG_PROJECTS_PUBLICATIONS_CONTENT_ERROR_LOAD_AUTHOR'));
+			$this->setError(Lang::txt('PLG_PROJECTS_PUBLICATIONS_CONTENT_ERROR_LOAD_AUTHOR'));
 			return false;
 		}
 
 		if ($row->deleteAssociationByOwner($row->project_owner_id, $row->publication_version_id))
 		{
-			$this->set('_message', Lang::txt('Author deleted') );
+			$this->set('_message', Lang::txt('Author deleted'));
 
 			// Reflect the update in curation record
 			$this->_parent->set('_update', 1);
@@ -731,45 +729,45 @@ class Authors extends Base
 	 * @param   string  $viewname
 	 * @return  string  HTML
 	 */
-	public function buildContent( $pub = null, $viewname = 'edit' )
+	public function buildContent($pub = null, $viewname = 'edit')
 	{
 		$name = $viewname == 'freeze' || $viewname == 'curator' ? 'freeze' : 'draft';
 
 		// Get selector styles
-		\Hubzero\Document\Assets::addPluginStylesheet('projects', 'team','selector');
+		\Hubzero\Document\Assets::addPluginStylesheet('projects', 'team', 'selector');
 
 		// Output HTML
 		$view = new \Hubzero\Plugin\View(
 			array(
-				'folder'	=> 'projects',
-				'element'	=> 'publications',
-				'name'		=> $name,
-				'layout'	=> 'authors'
+				'folder'  => 'projects',
+				'element' => 'publications',
+				'name'    => $name,
+				'layout'  => 'authors'
 			)
 		);
 
 		// Get authors
 		if (!isset($pub->_authors))
 		{
-			$pAuthors 			= new \Components\Publications\Tables\Author( $this->_parent->_db );
-			$pub->_authors 		= $pAuthors->getAuthors($pub->version_id);
-			$pub->_submitter 	= $pAuthors->getSubmitter($pub->version_id, $pub->created_by);
+			$pAuthors = new \Components\Publications\Tables\Author($this->_parent->_db);
+			$pub->_authors   = $pAuthors->getAuthors($pub->version_id);
+			$pub->_submitter = $pAuthors->getSubmitter($pub->version_id, $pub->created_by);
 		}
 
 		// Get creator groups
 		$view->groups = \Hubzero\User\Helper::getGroups($pub->_project->get('owned_by_user'), 'members', 1);
 
-		$view->pub		= $pub;
+		$view->pub      = $pub;
 		$view->manifest = $this->_manifest;
-		$view->step		= $this->_blockId;
+		$view->step     = $this->_blockId;
 
 		// Get team members
-		$objO = new \Components\Projects\Tables\Owner( $this->_parent->_db );
-		$view->teamids = $objO->getIds( $pub->_project->get('id'), 'all', 0, 0 );
+		$objO = new \Components\Projects\Tables\Owner($this->_parent->_db);
+		$view->teamids = $objO->getIds($pub->_project->get('id'), 'all', 0, 0);
 
 		if ($this->getError())
 		{
-			$view->setError( $this->getError() );
+			$view->setError($this->getError());
 		}
 		return $view->loadTemplate();
 	}
@@ -782,7 +780,7 @@ class Authors extends Base
 	 * @param   integer  $elementId
 	 * @return  object
 	 */
-	public function getStatus( $pub = null, $manifest = null, $elementId = null )
+	public function getStatus($pub = null, $manifest = null, $elementId = null)
 	{
 		// Set block manifest
 		if ($this->_manifest === null)
@@ -791,18 +789,18 @@ class Authors extends Base
 		}
 
 		// Start status
-		$status 	 = new \Components\Publications\Models\Status();
+		$status = new \Components\Publications\Models\Status();
 
 		// Get authors
 		if (!isset($pub->_authors))
 		{
-			$pAuthors 			= new \Components\Publications\Tables\Author( $this->_parent->_db );
-			$pub->_authors 		= $pAuthors->getAuthors($pub->version_id);
-			$pub->_submitter 	= $pAuthors->getSubmitter($pub->version_id, $pub->created_by);
+			$pAuthors = new \Components\Publications\Tables\Author($this->_parent->_db);
+			$pub->_authors = $pAuthors->getAuthors($pub->version_id);
+			$pub->_submitter = $pAuthors->getSubmitter($pub->version_id, $pub->created_by);
 		}
 
 		// Are authors required?
-		$required 	 	= $this->_manifest->params->required;
+		$required = $this->_manifest->params->required;
 		$status->status = $required && (!$pub->_authors || count($pub->_authors) == 0) ? 0 : 1;
 
 		if ($status->status == 0)
