@@ -163,9 +163,9 @@ class Elements
 			// Traverse the registry to find the correct node for the result.
 			for ($i = 0,$n = count($nodes); $i < $n; $i++)
 			{
-				if (isset($node->$nodes[$i]))
+				if (isset($node->{$nodes[$i]}))
 				{
-					$node = $node->$nodes[$i];
+					$node = $node->{$nodes[$i]};
 				}
 				else
 				{
@@ -416,15 +416,15 @@ class Elements
 			// Traverse the registry to find the correct node for the result.
 			for ($i = 0, $n = count($nodes) - 1; $i < $n; $i++)
 			{
-				if (!isset($node->$nodes[$i]) && ($i != $n))
+				if (!isset($node->{$nodes[$i]}) && ($i != $n))
 				{
-					$node->$nodes[$i] = new stdClass;
+					$node->{$nodes[$i]} = new stdClass;
 				}
-				$node = $node->$nodes[$i];
+				$node = $node->{$nodes[$i]};
 			}
 
 			// Get the old value if exists so we can return it
-			$result = $node->$nodes[$i] = $value;
+			$result = $node->{$nodes[$i]} = $value;
 		}
 
 		return $result;
