@@ -32,8 +32,11 @@
 
 namespace Components\Publications\Site\Controllers;
 
+require_once Component::path('com_publications') . '/models/bundle.php';
+
 use Hubzero\Component\SiteController;
 use Components\Publications\Tables;
+use Components\Publications\Models\Bundle;
 use Components\Publications\Models;
 use Components\Publications\Helpers;
 use Component;
@@ -90,7 +93,7 @@ class Publications extends SiteController
 		$this->registerTask('start', 'contribute');
 		$this->registerTask('publication', 'contribute');
 
-		$this->_task = trim(Request::getVar('task', ''));
+		$this->_task = trim(Request::getCmd('task', ''));
 		if (($this->_id || $this->_alias) && !$this->_task)
 		{
 			$this->_task = 'page';
@@ -137,8 +140,8 @@ class Publications extends SiteController
 	protected function _incoming()
 	{
 		$this->_id      = Request::getInt('id', 0);
-		$this->_alias   = Request::getVar('alias', '');
-		$this->_version = Request::getVar('v', 'default');
+		$this->_alias   = Request::getString('alias', '');
+		$this->_version = Request::getString('v', 'default');
 
 		$this->_identifier = $this->_alias ? $this->_alias : $this->_id;
 
@@ -323,7 +326,7 @@ class Publications extends SiteController
 	 */
 	protected function _login()
 	{
-		$rtrn = Request::getVar('REQUEST_URI', Route::url('index.php?option=' . $this->_option . '&task=' . $this->_task), 'server');
+		$rtrn = Request::getString('REQUEST_URI', Route::url('index.php?option=' . $this->_option . '&task=' . $this->_task), 'server');
 
 		App::redirect(
 			Route::url('index.php?option=com_users&view=login&return=' . base64_encode($rtrn)),
@@ -413,12 +416,12 @@ class Publications extends SiteController
 
 		// Incoming
 		$this->view->filters = array(
-			'category'    => Request::getVar('category', ''),
+			'category'    => Request::getString('category', ''),
 			'sortby'      => Request::getCmd('sortby', $default_sort),
 			'limit'       => Request::getInt('limit', Config::get('list_limit')),
 			'start'       => Request::getInt('limitstart', 0),
-			'search'      => Request::getVar('search', ''),
-			'tag'         => trim(Request::getVar('tag', '', 'request', 'none', 2)),
+			'search'      => Request::getString('search', ''),
+			'tag'         => trim(Request::getString('tag', '', 'request')),
 			'tag_ignored' => array()
 		);
 
@@ -543,7 +546,7 @@ class Publications extends SiteController
 		$this->view->setName('view');
 
 		// Incoming
-		$tab      = Request::getVar('active', '');   // The active tab (section)
+		$tab      = Request::getString('active', '');   // The active tab (section)
 		$no_html  = Request::getInt('no_html', 0);   // No-html display?
 
 		// Ensure we have an ID or alias to work with
@@ -657,18 +660,26 @@ class Publications extends SiteController
 		$body = '';
 		if ($tab == 'about')
 		{
+			$publicationVersionId = $this->model->get('version_id');
+			$bundle = new Bundle([
+				'publication_id' => $this->model->get('id'),
+				'publication_version_id' => $publicationVersionId
+			]);
 			// Build the HTML of the "about" tab
 			$view = new \Hubzero\Component\View(array(
 				'name'   => 'about',
 				'layout' => 'default'
 			));
 			$view->option      = $this->_option;
+			$view->controller  = $this->_controller;
+			$view->task        = $this->_task;
 			$view->config      = $this->config;
 			$view->database    = $this->database;
 			$view->publication = $this->model;
 			$view->authorized  = $authorized;
 			$view->restricted  = $restricted;
-			$view->version     = $this->model->versionAlias;
+			$view->version     = $publicationVersionId;
+			$view->bundle      = $bundle;
 			$view->sections    = $sections;
 			$body              = $view->loadTemplate();
 
@@ -690,7 +701,7 @@ class Publications extends SiteController
 		$defaultsort = ($this->model->_category->alias == 'series' && $this->config->get('show_ranking')) ? 'ranking' : $defaultsort;
 
 		$filters = array(
-			'sortby' => Request::getVar('sortby', $defaultsort),
+			'sortby' => Request::getString('sortby', $defaultsort),
 			'limit'  => Request::getInt('limit', 0),
 			'start'  => Request::getInt('limitstart', 0),
 			'id'     => $this->model->publication->id
@@ -740,10 +751,10 @@ class Publications extends SiteController
 		// Incoming
 		$aid        = Request::getInt('a', 0);             // Attachment id
 		$elementId  = Request::getInt('el', 1);            // Element id
-		$render     = Request::getVar('render', '');
+		$render     = Request::getString('render', '');
 		$vid        = Request::getInt('vid', '');
-		$file       = Request::getVar('file', '');
-		$disp       = Request::getVar('disposition');
+		$file       = Request::getString('file', '');
+		$disp       = Request::getString('disposition');
 		$disp       = in_array($disp, array('inline', 'attachment')) ? $disp : 'attachment';
 
 		// Get our model and load publication data
@@ -955,7 +966,7 @@ class Publications extends SiteController
 	public function citationTask()
 	{
 		// Incoming
-		$format = Request::getVar('type', 'bibtex');
+		$format = Request::getString('type', 'bibtex');
 
 		// Get our model and load publication data
 		$this->model = new Models\Publication($this->_identifier, $this->_version);
@@ -1088,7 +1099,7 @@ class Publications extends SiteController
 	public function pluginTask()
 	{
 		// Incoming
-		$trigger = trim(Request::getVar('trigger', ''));
+		$trigger = trim(Request::getString('trigger', ''));
 
 		// Ensure we have a trigger
 		if (!$trigger)
@@ -1197,8 +1208,8 @@ class Publications extends SiteController
 	{
 		// Incoming
 		$pid     = Request::getInt('pid', 0);
-		$action  = Request::getVar('action', '');
-		$active  = Request::getVar('active', 'publications');
+		$action  = Request::getString('action', '');
+		$active  = Request::getString('active', 'publications');
 		$action  = $this->_task == 'start' ? 'start' : $action;
 		$ajax    = Request::getInt('ajax', 0);
 		$doiErr  = Request::getInt('doierr', 0);
@@ -1362,7 +1373,7 @@ class Publications extends SiteController
 
 		// Incoming
 		$id      = Request::getInt('id', 0);
-		$tags    = Request::getVar('tags', '');
+		$tags    = Request::getString('tags', '');
 		$no_html = Request::getInt('no_html', 0);
 
 		// Process tags
@@ -1642,6 +1653,7 @@ class Publications extends SiteController
 			$owners[$owner->userid] = $owner->id;
 		}
 
+		$isAlreadyAuthor = false;
 		foreach ($authors as $author)
 		{
 			$owner_id = $author->get('project_owner_id');
@@ -1677,26 +1689,34 @@ class Publications extends SiteController
 			{
 				App::abort(500, $author->getError());
 			}
+
+			if ($author->get('user_id') == User::get('id'))
+			{
+				$isAlreadyAuthor = true;
+			}
 		}
 
 		// Add the user as the author of the publication
-		$author = Models\Orm\Author::blank();
-		$author->set('user_id', User::get('id'));
-		$author->set('name', User::get('name'));
-		$author->set('firstName', User::get('givenName'));
-		$author->set('lastName', User::get('surname'));
-		$author->set('organization', User::get('organization'));
-		$author->set('status', 1);
-		$author->set('publication_version_id', $version->get('id'));
-		$author->set('project_owner_id', $owners[$author->get('user_id')]);
-		$author->set('created', Date::of('now')->toSql());
-		$author->set('created_by', User::get('id'));
-		$author->set('modified', '0000-00-00 00:00:00');
-		$author->set('modified_by', 0);
-
-		if (!$author->save())
+		if (!$isAlreadyAuthor)
 		{
-			App::abort(500, $author->getError());
+			$author = Models\Orm\Author::blank();
+			$author->set('user_id', User::get('id'));
+			$author->set('name', User::get('name'));
+			$author->set('firstName', User::get('givenName'));
+			$author->set('lastName', User::get('surname'));
+			$author->set('organization', User::get('organization'));
+			$author->set('status', 1);
+			$author->set('publication_version_id', $version->get('id'));
+			$author->set('project_owner_id', $owners[$author->get('user_id')]);
+			$author->set('created', Date::of('now')->toSql());
+			$author->set('created_by', User::get('id'));
+			$author->set('modified', '0000-00-00 00:00:00');
+			$author->set('modified_by', 0);
+
+			if (!$author->save())
+			{
+				App::abort(500, $author->getError());
+			}
 		}
 
 		// Copy attachments
