@@ -36,7 +36,7 @@ $canDo = \Components\Resources\Helpers\Permissions::getActions('type');
 
 $text = ($this->task == 'edit' ? Lang::txt('JACTION_EDIT') : Lang::txt('JACTION_CREATE'));
 
-Toolbar::title(Lang::txt('COM_RESOURCES') . ': ' . Lang::txt('COM_RESOURCES_TYPES') . ': ' . $text, 'addedit.png');
+Toolbar::title(Lang::txt('COM_RESOURCES') . ': ' . Lang::txt('COM_RESOURCES_TYPES') . ': ' . $text, 'resources');
 if ($canDo->get('core.edit'))
 {
 	Toolbar::save();
@@ -47,7 +47,7 @@ Html::behavior('framework', true);
 
 $this->css();
 
-$params = new \Hubzero\Config\Registry($this->row->params);
+$params = new \Hubzero\Config\Registry($this->row->get('params'));
 ?>
 <script type="text/javascript">
 function submitbutton(pressbutton)
@@ -91,6 +91,10 @@ function submitbutton(pressbutton)
 					<label for="field-contributable"><?php echo Lang::txt('COM_RESOURCES_FIELD_CONTRIBUTABLE'); ?>:</label><br />
 					<input type="checkbox" name="type[contributable]" id="field-contributable" value="1"<?php echo ($this->row->contributable) ? ' checked="checked"' : ''; ?> /> <?php echo Lang::txt('COM_RESOURCES_FIELD_CONTRIBUTABLE_EXPLANATION'); ?>
 				</div>
+				<div class="input-wrap">
+					<label for="field-collection"><?php echo Lang::txt('COM_RESOURCES_FIELD_COLLECTION'); ?>:</label><br />
+					<input type="checkbox" name="type[collection]" id="field-collection" value="1"<?php echo ($this->row->collection) ? ' checked="checked"' : ''; ?> /> <?php echo Lang::txt('COM_RESOURCES_FIELD_COLLECTION_EXPLANATION'); ?>
+				</div>
 				<?php if ($this->row->category != 27) { ?>
 					<div class="input-wrap">
 						<label for="params-linkaction"><?php echo Lang::txt('COM_RESOURCES_FIELD_LINKED_ACTION'); ?>:</label><br />
@@ -101,6 +105,19 @@ function submitbutton(pressbutton)
 							<option value="download"<?php echo ($params->get('linkAction') == 'download') ? ' selected="selected"':''; ?>><?php echo Lang::txt('COM_RESOURCES_FIELD_LINKED_ACTION_DOWNLOAD'); ?></option>
 						</select>
 					</div>
+					<div class="input-wrap">
+						<label for="param-restrict_direct_access"><?php echo Lang::txt('COM_RESOURCES_FIELD_RESTRICT_DIRECT_ACCESS_HINT'); ?>:</label><br />
+						<select name="params[restrict_direct_access]" id="param-link_action">
+							<option value="0"<?php if (!$params->get('restrict_direct_access')) { echo ' selected="selected"'; } ?>>
+								<?php echo Lang::txt('COM_RESOURCES_FIELD_RESTRICT_DIRECT_ACCESS_DEFAULT'); ?></option>
+							<option value="1"<?php if ($params->get('restrict_direct_access') == 1) { echo ' selected="selected"'; } ?>>
+								<?php echo Lang::txt('COM_RESOURCES_FIELD_RESTRICT_DIRECT_ACCESS_NO'); ?>
+							</option>
+							<option value="2"<?php if ($params->get('restrict_direct_access') == 2) { echo ' selected="selected"'; } ?>>
+								<?php echo Lang::txt('COM_RESOURCES_FIELD_RESTRICT_DIRECT_ACCESS_YES'); ?>
+							</option>
+						</select>
+					</div>
 				<?php } ?>
 				<div class="input-wrap">
 					<label for="field-state"><?php echo Lang::txt('COM_RESOURCES_FIELD_STATE'); ?>:</label><br />
@@ -138,17 +155,21 @@ function submitbutton(pressbutton)
 					$plugins = $database->loadObjectList();
 
 					$found = array();
+					$lang = Lang::getRoot();
 					foreach ($plugins as $plugin)
 					{
 						if (in_array('plg_' . $plugin->element, $found))
 						{
 							continue;
 						}
+						$path = Plugin::path($plugin->folder, $plugin->element);
+
 						$found[] = 'plg_' . $plugin->element;
 						if (strstr($plugin->name, '_'))
 						{
-							$lang = Lang::getRoot();
-							$lang->load($plugin->name);
+							$lang->load($plugin->name . '.sys') ||
+							$lang->load($plugin->name . '.sys', PATH_APP . '/plugins/' . $plugin->folder . '/' . $plugin->element) ||
+							$lang->load($plugin->name . '.sys', PATH_CORE . '/plugins/' . $plugin->folder . '/' . $plugin->element);
 						}
 						?>
 						<tr>
@@ -189,7 +210,7 @@ function submitbutton(pressbutton)
 			</tfoot>
 			<tbody id="field-items">
 			<?php
-			include_once(PATH_CORE . DS . 'components' . DS . 'com_resources' . DS . 'models' . DS . 'elements.php');
+			include_once Component::path('com_resources') . DS . 'models' . DS . 'elements.php';
 			$elements = new \Components\Resources\Models\Elements('', $this->row->customFields);
 			$schema = $elements->getSchema();
 
@@ -416,4 +437,4 @@ function submitbutton(pressbutton)
 	</fieldset>
 
 	<?php echo Html::input('token'); ?>
-</form>
\ No newline at end of file
+</form>
