@@ -97,7 +97,7 @@ class Media extends SiteController
 		}
 
 		// Incoming file
-		$file = Request::getVar('upload', '', 'files', 'array');
+		$file = Request::getArray('upload', '', 'files');
 		if (!$file['name'])
 		{
 			$this->setError(Lang::txt('RESOURCES_NO_FILE'));
@@ -182,7 +182,7 @@ class Media extends SiteController
 		}
 
 		// Incoming file to delete
-		$file = Request::getVar('file', '');
+		$file = Request::getString('file', '');
 
 		if (!$file)
 		{
