@@ -41,10 +41,6 @@ Submenu::addEntry(
 	Lang::txt('Overview'),
 	'index.php?option='.$option.'&task=configure'
 );
-Submenu::addEntry(
-	Lang::txt('Search Index'),
-	'index.php?option='.$option.'&task=searchindex'
-);
 Submenu::addEntry(
 	Lang::txt('Searchable Components'),
 	'index.php?option='.$option.'&task=display&controller=searchable'
