@@ -12,7 +12,25 @@ $(function(){
 		$('#actags').data("tokenInputObject").add(tag);
 		$('#actags').parent('form').submit();
 	});
-	
+	var minDate = $('.datetimepicker[data-mindate]').data('mindate');
+	var maxDate = $('.datetimepicker[data-maxdate]').data('maxdate');
+	if (minDate)
+	{
+		$('.datetimepicker[data-mindate]').datetimepicker({
+			format: 'Y-m-d H:00:00',
+			minDate: new Date(minDate)
+		});
+	}	
+	if (maxDate)
+	{
+		$('.datetimepicker[data-maxdate]').datetimepicker({
+			format: 'Y-m-d H:00:00',
+			maxDate: new Date(maxDate)
+		});
+	}	
+	$('.datetimepicker').datetimepicker({
+		format: 'Y-m-d H:00:00'
+	});
 	// Submit query using any new tags added when filtering on category
 	$('a[data-type]').on('click', function(e){
 		e.preventDefault();
