@@ -32,7 +32,7 @@
 // No direct access
 defined('_HZEXEC_') or die();
 
-$tmpl = Request::getVar('tmpl', '');
+$tmpl = Request::getCmd('tmpl', '');
 
 $text = 'Add user';
 
@@ -86,8 +86,8 @@ jQuery(document).ready(function($){
 	<fieldset>
 		<div class="configuration" >
 			<div class="fltrt configuration-options">
-				<button type="button" onclick="submitbutton('addusers');"><?php echo Lang::txt( 'Save' );?></button>
-				<button type="button" onclick="window.parent.$.fancybox.close();"><?php echo Lang::txt( 'Cancel' );?></button>
+				<button type="button" onclick="submitbutton('addusers');"><?php echo Lang::txt('Save');?></button>
+				<button type="button" onclick="window.parent.$.fancybox.close();"><?php echo Lang::txt('Cancel');?></button>
 			</div>
 			<?php echo Lang::txt('Add new users') ?>
 		</div>
