@@ -186,13 +186,13 @@ function submitbutton(pressbutton)
 		</div>
 	</div>
 
-	<input type="hidden" name="ticket[referrer]" value="<?php echo Request::getVar('HTTP_REFERER', NULL, 'server'); ?>" />
+	<input type="hidden" name="ticket[referrer]" value="<?php echo Request::getString('HTTP_REFERER', NULL, 'server'); ?>" />
 	<input type="hidden" name="ticket[os]" value="<?php echo $browser->platform(); ?>" />
 	<input type="hidden" name="osver" value="<?php echo $browser->platformVersion(); ?>" />
 	<input type="hidden" name="ticket[browser]" value="<?php echo $browser->name(); ?>" />
 	<input type="hidden" name="browserver" value="<?php echo $browser->version(); ?>" />
-	<input type="hidden" name="ticket[hostname]" value="<?php echo gethostbyaddr(Request::getVar('REMOTE_ADDR','','server')); ?>" />
-	<input type="hidden" name="ticket[uas]" value="<?php echo Request::getVar('HTTP_USER_AGENT', '', 'server'); ?>" />
+	<input type="hidden" name="ticket[hostname]" value="<?php echo gethostbyaddr(Request::getString('REMOTE_ADDR','','server')); ?>" />
+	<input type="hidden" name="ticket[uas]" value="<?php echo Request::getString('HTTP_USER_AGENT', '', 'server'); ?>" />
 	<input type="hidden" name="ticket[open]" value="1" />
 
 	<input type="hidden" name="id" id="ticketid" value="<?php echo $this->row->get('id'); ?>" />
