@@ -474,7 +474,7 @@ if (!$no_html)
 						<fieldset>
 							<legend><?php echo Lang::txt('COM_SUPPORT_TICKET_COMMENT_LEGEND_ATTACHMENTS'); ?></legend>
 							<?php
-							$tmp = Request::getVar('tmp_dir', ('-' . time()), 'post');
+							$tmp = Request::getString('tmp_dir', ('-' . time()), 'post');
 							if (!$no_html) {
 								$this->js('jquery.fileuploader.js', 'system');
 							}
