@@ -118,7 +118,7 @@ class Queries extends SiteController
 		Request::checkToken();
 
 		// Incoming
-		$fields  = Request::getVar('fields', array(), 'post');
+		$fields  = Request::getArray('fields', array(), 'post');
 		$no_html = Request::getInt('no_html', 0);
 		$tmpl    = Request::getCmd('component', '');
 
@@ -249,7 +249,7 @@ class Queries extends SiteController
 
 		if (!is_object($row))
 		{
-			$id = Request::getVar('id', array(0));
+			$id = Request::getArray('id', array(0));
 			if (is_array($id))
 			{
 				$id = (!empty($id) ? intval($id[0]) : 0);
@@ -287,7 +287,7 @@ class Queries extends SiteController
 		Request::checkToken(['get', 'post']);
 
 		// Incoming
-		$fields  = Request::getVar('fields', array());
+		$fields  = Request::getArray('fields', array());
 		$no_html = Request::getInt('no_html', 0);
 		$tmpl    = Request::getString('component', '');
 
@@ -344,7 +344,7 @@ class Queries extends SiteController
 		Request::checkToken(['get', 'post']);
 
 		// Incoming
-		$ids = Request::getVar('id', array());
+		$ids = Request::getArray('id', array());
 		$ids = (is_array($ids) ?: array($ids));
 
 		$no_html = Request::getInt('no_html', 0);
@@ -379,8 +379,8 @@ class Queries extends SiteController
 		Request::checkToken(['get', 'post']);
 
 		// Incoming
-		$folders = Request::getVar('folder', array());
-		$queries = Request::getVar('queries', array());
+		$folders = Request::getArray('folder', array());
+		$queries = Request::getArray('queries', array());
 
 		if (is_array($folders))
 		{
