@@ -39,6 +39,7 @@ use Components\Support\Models\Comment;
 use Components\Support\Models\Tags;
 use Components\Support\Models\Attachment;
 use Components\Support\Models\QueryFolder;
+use Components\Support\Models\Query;
 use Components\Support\Models\Watching;
 use Components\Support\Models\Category;
 use Components\Support\Models\Message;
@@ -883,8 +884,8 @@ class Tickets extends SiteController
 			// This really, REALLY shouldn't happen.
 			App::abort(400, Lang::txt('COM_SUPPORT_ERROR_MISSING_DATA'));
 		}
-		$reporter = Request::getVar('reporter', array(), 'post', 'none', 2);
-		$problem  = Request::getVar('problem', array(), 'post', 'none', 2);
+		$reporter = Request::getArray('reporter', array(), 'post');
+		$problem  = Request::getArray('problem', array(), 'post');
 
 		$reporter = array_map(array('\\Hubzero\\Utility\\Sanitize', 'stripAll'), $reporter);
 
@@ -1687,8 +1688,8 @@ class Tickets extends SiteController
 			App::abort(500, Lang::txt('COM_SUPPORT_ERROR_MISSING_TICKET_ID'));
 		}
 
-		$comment  = Request::getString('comment', '', 'post', 'none', 2);
-		$incoming = Request::getVar('ticket', array(), 'post');
+		$comment  = Request::getString('comment', '', 'post');
+		$incoming = Request::getArray('ticket', array(), 'post');
 		$incoming = array_map('trim', $incoming);
 
 		if (isset($incoming['target_date']))
@@ -2425,7 +2426,7 @@ class Tickets extends SiteController
 		}
 
 		// Incoming file
-		$file = Request::getVar('upload', array(), 'files', 'array');
+		$file = Request::getArray('upload', array(), 'files');
 		if (!isset($file['name']) || !$file['name'])
 		{
 			//$this->setError(Lang::txt('SUPPORT_NO_FILE'));
@@ -2740,7 +2741,7 @@ class Tickets extends SiteController
 						foreach ($members as $member)
 						{
 							$u = User::getInstance($member);
-							if (!is_object($u))
+							if (!(is_object($u) && $u->get('block') == '0'))
 							{
 								continue;
 							}
@@ -2768,7 +2769,7 @@ class Tickets extends SiteController
 				foreach ($members as $member)
 				{
 					$u = User::getInstance($member);
-					if (!is_object($u))
+					if (!(is_object($u) && $u->get('block') == '0'))
 					{
 						continue;
 					}
