@@ -80,7 +80,8 @@ class Utils
 			}
 			else
 			{
-				$instance = \JDatabase::getInstance($options);
+				$options['driver'] = ($options['driver'] == 'mysql') ? 'pdo' : $options['driver'];
+				$instance = \Hubzero\Database\Driver::getInstance($options);
 				if ($instance instanceof Exception)
 				{
 					$instance = \App::get('db');
@@ -300,7 +301,7 @@ class Utils
 	public static function getResourcePath($createdDate, $resourceId, $versionId)
 	{
 		//include the resources html helper file
-		include_once(PATH_CORE . DS . 'components' . DS . 'com_resources' . DS . 'helpers' . DS . 'html.php');
+		include_once \Component::path('com_resources') . DS . 'helpers' . DS . 'html.php';
 
 		//get resource upload path
 		$resourceParams = Component::params('com_resources');
@@ -415,7 +416,7 @@ class Utils
 		}
 
 		//get access settings
-		$exportAllowed = \Components\Tools\Helpers\Utils::getToolExportAccess($toolVersion->exportControl);
+		$exportAllowed = self::getToolExportAccess($toolVersion->exportControl);
 		$isToolPublished = ($toolVersion->state == 1);
 		$isToolDev = ($toolVersion->state == 3);
 		$isGroupControlled = ($toolVersion->toolaccess == '@GROUP');
