@@ -56,7 +56,7 @@ if (($cookie = \Hubzero\Utility\Cookie::eat('authenticator')) && !Request::getIn
 		if (isset($cookie->user_id))
 		{
 			$user     = User::getInstance($cookie->user_id);
-			$user_img = $cookie->user_img;
+			$user_img = isset($cookie->user_img) ? $cookie->user_img : '';
 			Request::setVar('primary', $primary);
 		}
 	}
@@ -101,6 +101,11 @@ if ($primary != 'hubzero' && !isset($refl[$primary]))
 				<?php echo $this->escape($errorText); ?>
 			</p>
 		<?php endif; ?>
+		<?php if ($this->description) : ?>
+			<p>
+				<?php echo $this->escape($this->description); ?>
+			</p>
+		<?php endif; ?>
 <?php if ($this->totalauths) : ?>
 	<?php if ($primary && $primary != 'hubzero') : ?>
 		<a class="primary" href="<?php echo Route::url('index.php?option=com_users&view=login&authenticator=' . $primary . $this->returnQueryString); ?>">
@@ -156,7 +161,7 @@ if ($primary != 'hubzero' && !isset($refl[$primary]))
 						<?php endif; ?>
 						<div class="label-input-pair">
 							<label for="password"><?php echo Lang::txt('COM_USERS_LOGIN_PASSWORD'); ?>:</label>
-							<input tabindex="2" type="password" name="passwd" id="password" class="passwd" placeholder="<?php echo strtolower(Lang::txt('COM_USERS_LOGIN_PASSWORD')); ?>" />
+							<input tabindex="2" type="password" name="passwd" id="password" class="passwd" placeholder="<?php echo strtolower(Lang::txt('COM_USERS_LOGIN_PASSWORD')); ?>" autocomplete="off" />
 							<div class="spinner">
 								<div class="bounce1"></div>
 								<div class="bounce2"></div>
