@@ -43,15 +43,6 @@ class Migration20150626201931Core extends Base
 				$this->setError('Unable to create new site directory (there was no old site directory).', 'warning');
 				return false;
 			}
-
-			chmod($new, 0775);
-			if (posix_getuid() == 0)
-			{
-				chown($new, fileowner(PATH_ROOT));
-				chgrp($new, filegroup(PATH_ROOT));
-			}
-
-
 		}
 		else if (is_dir($old) && is_dir($new))
 		{
@@ -95,18 +86,11 @@ class Migration20150626201931Core extends Base
 		}
 		else if (!is_dir($old) && !is_dir($new))
 		{
-			if (!mkdir($new,0775))
+			if (!mkdir($new, 0775))
 			{
 				$this->setError('Unable to create new site directory (there was no old site directory).', 'warning');
 				return false;
 			}
-
-			chmod($new, 0775);
-			if (posix_getuid() == 0)
-			{
-				chown($new, fileowner(PATH_ROOT));
-				chgrp($new, filegroup(PATH_ROOT));
-			}
 		}
 		else if (is_dir($old) && is_dir($new))
 		{
