@@ -9,7 +9,7 @@ defined('_HZEXEC_') or die();
  * Migration script to change database engine for a few core tables that could have been missed
  **/
 class Migration20160907104900Core extends Base
-{	
+{
 	private function changeEngine($table, $engine)
 	{
 		if ($this->db->tableExists($table) && strtolower($this->db->getEngine($table)) != $engine)
@@ -29,8 +29,5 @@ class Migration20160907104900Core extends Base
 
 	public function down()
 	{
-		$this->changeEngine('#__viewlevels', 'Innodb');
-		$this->changeEngine('#__languages', 'Innodb');
-		$this->changeEngine('#__associations', 'Innodb');
 	}
 }
