@@ -28,7 +28,5 @@ class Migration20160907105300ComUsers extends Base
 
 	public function down()
 	{
-		$this->changeEngine('#__users_tool_preferences', 'Innodb');
-		$this->changeEngine('#__users_quotas_classes_groups', 'Innodb');
 	}
 }
