@@ -84,7 +84,7 @@ class plgAuthenticationCertificate extends \Hubzero\Plugin\Plugin
 	public function login(&$credentials, &$options)
 	{
 		// Check for return param
-		if ($return = Request::getVar('return', '', 'method', 'base64'))
+		if ($return = Request::getString('return', ''))
 		{
 			$return = base64_decode($return);
 			if (!\Hubzero\Utility\Uri::isInternal($return))
