@@ -70,12 +70,14 @@ $option = 'com_groups';
 	<?php //if ($this->authorized == 'manager' || $this->authorized == 'admin') { ?>
 		<ul id="page_options">
 			<li>
-				<?php if ($this->authorized == 'manager'
-					|| $this->authorized == 'admin'
-					|| Components\Groups\Helpers\Permissions::userHasPermissionForGroupAction($this->group, 'group.invite')) : ?>
-				<a class="icon-add add btn" href="<?php echo Route::url('index.php?option=' . $option . '&cn=' . $this->group->get('cn') . '&task=invite'); ?>">
-					<?php echo Lang::txt('PLG_GROUPS_MEMBERS_INVITE_MEMBERS'); ?>
-				</a>
+				<?php if ($this->group->get('join_policy') < 3) : ?>
+					<?php if ($this->authorized == 'manager'
+						|| $this->authorized == 'admin'
+						|| Components\Groups\Helpers\Permissions::userHasPermissionForGroupAction($this->group, 'group.invite')) : ?>
+					<a class="icon-add add btn" href="<?php echo Route::url('index.php?option=' . $option . '&cn=' . $this->group->get('cn') . '&task=invite'); ?>">
+						<?php echo Lang::txt('PLG_GROUPS_MEMBERS_INVITE_MEMBERS'); ?>
+					</a>
+					<?php endif; ?>
 				<?php endif; ?>
 				<?php if ($this->membership_control == 1 && $this->authorized == 'manager') : ?>
 					<a class="icon-add add btn" href="<?php echo Route::url('index.php?option='.$option.'&cn='.$this->group->cn.'&active=members&action=addrole'); ?>">
