@@ -489,6 +489,8 @@ class plgMembersBlog extends \Hubzero\Plugin\Plugin
 			$filters['access'] = User::getAuthorisedViewLevels();
 		}
 
+		Event::trigger('blog.onBlogView', array($row));
+
 		$view = $this->view('default', 'entry')
 			->set('option', $this->option)
 			->set('member', $this->member)
@@ -600,7 +602,7 @@ class plgMembersBlog extends \Hubzero\Plugin\Plugin
 		// Check for request forgeries
 		Request::checkToken();
 
-		$entry = Request::getVar('entry', array(), 'post', 'none', 2);
+		$entry = Request::getArray('entry', array(), 'post');
 
 		if (isset($entry['publish_up']) && $entry['publish_up'] != '')
 		{
@@ -752,7 +754,7 @@ class plgMembersBlog extends \Hubzero\Plugin\Plugin
 		Request::checkToken();
 
 		// Incoming
-		$data = Request::getVar('comment', array(), 'post', 'none', 2);
+		$data = Request::getArray('comment', array(), 'post');
 
 		// Instantiate a new comment object and pass it the data
 		$comment = \Components\Blog\Models\Comment::oneOrNew($data['id'])->set($data);
@@ -917,11 +919,11 @@ class plgMembersBlog extends \Hubzero\Plugin\Plugin
 		Request::checkToken();
 
 		// Incoming
-		$settings = Request::getVar('settings', array(), 'post');
+		$settings = Request::getArray('settings', array(), 'post');
 
 		$row = \Hubzero\Plugin\Params::blank()->set($settings);
 
-		$p = new \Hubzero\Config\Registry(Request::getVar('params', array(), 'post'));
+		$p = new \Hubzero\Config\Registry(Request::getArray('params', array(), 'post'));
 
 		$row->set('params', $p->toString());
 
