@@ -205,7 +205,7 @@ class plgMembersCitations extends \Hubzero\Plugin\Plugin
 	private function browseAction()
 	{
 		 // Instantiate a new citations object
-		$obj = $this->_filterHandler(Request::getVar('filters', array()), $this->member->get('id'));
+		$obj = $this->_filterHandler(Request::getArray('filters', array()), $this->member->get('id'));
 
 		$count = clone $obj['citations'];
 		$count = $count->count();
@@ -315,7 +315,7 @@ class plgMembersCitations extends \Hubzero\Plugin\Plugin
 		}
 		else
 		{
-			$view->filters['idlist'] = Request::getVar('idlist', $session->get('idlist'));
+			$view->filters['idlist'] = Request::getString('idlist', $session->get('idlist'));
 			$session->set('idlist', $view->filters['idlist']);
 		}
 
@@ -706,7 +706,7 @@ class plgMembersCitations extends \Hubzero\Plugin\Plugin
 		// Incoming
 		$id = Request::getInt('cid', 0);
 		$citationIDs = Request::getString('citationIDs', '');
-		$bulk = Request::getVar('bulk', false);
+		$bulk = Request::getBool('bulk', false);
 
 		// for single citation operation
 		if ($id != 0 && !$bulk)
@@ -929,8 +929,8 @@ class plgMembersCitations extends \Hubzero\Plugin\Plugin
 	private function publishAction()
 	{
 		$id = Request::getInt('cid', 0);
-		$citationIDs = Request::getVar('citationIDs', array());
-		$bulk = Request::getVar('bulk', false);
+		$citationIDs = Request::getString('citationIDs', '');
+		$bulk = Request::getBool('bulk', false);
 
 		if ($id != 0 && !$bulk)
 		{
@@ -1267,10 +1267,10 @@ class plgMembersCitations extends \Hubzero\Plugin\Plugin
 		$cites_require_no_attention = $this->importer->readRequiresNoAttention();
 
 		// action for citations needing attention
-		$citations_action_attention    = Request::getVar('citation_action_attention', array());
+		$citations_action_attention    = Request::getArray('citation_action_attention', array());
 
 		// action for citations needing no attention
-		$citations_action_no_attention = Request::getVar('citation_action_no_attention', array());
+		$citations_action_no_attention = Request::getArray('citation_action_no_attention', array());
 
 		// check to make sure we have citations
 		if (!$cites_require_attention && !$cites_require_no_attention)
