@@ -130,6 +130,12 @@ foreach ($profiles as $profile)
 	}
 }
 
+/**
+* Renders if argument is json?
+*
+* @param  string  $v
+* @return string
+*/
 function renderIfJson($v)
 {
 	if (strstr($v, '{'))
@@ -333,36 +339,74 @@ $legacy = array(
 			</li>
 		<?php endif; ?>
 
-		<?php if (!Plugin::isEnabled('members', 'account')) : ?>
-			<?php if ($isUser) : ?>
+		<?php if ($isUser) : ?>
+			<?php
+			// Determine what type of password change the user needs
+			$hzup = \Hubzero\User\Password::getInstance($this->profile->get('id'));
+			if ($hzup && !empty($hzup->passhash))
+			{
+				// A password has already been set, now check if they're logged in with a linked account
+				if (array_key_exists('auth_link_id', User::toArray()))
+				{
+					// Logged in with linked account
+					$passtype = 'changelocal';
+				}
+				else
+				{
+					// Logged in with hub
+					$passtype = 'changehub';
+				}
+			}
+			else
+			{
+				// No password has been set...
+				$passtype = 'set';
+			}
+			?>
+			<?php if (!Plugin::isEnabled('members', 'account')) : ?>
 				<li class="profile-password section hidden">
 					<div class="section-content">
 						<div class="key"><?php echo Lang::txt('PLG_MEMBERS_PROFILE_PASSWORD'); ?></div>
-						<div class="value">***************</div>
+						<div class="value">
+							<?php
+							// Determine what type of password change the user needs
+							if ($passtype == 'changelocal' || $passtype == 'changehub')
+							{
+								echo '***************';
+							}
+							else
+							{
+								// No password has been set...
+								echo Lang::txt('PLG_MEMBERS_PROFILE_PASSWORD_NOT_SET');
+							}
+							?>
+						</div>
 						<br class="clear" />
 						<div class="section-edit-container">
-							<?php /*
-							<div class="edit-profile-title"><h2>Change Password</h2></div>
-							<a href="#" class="edit-profile-close">&times;</a>
-							*/ ?>
 							<div class="section-edit-content">
 								<form action="<?php echo Route::url('index.php?option=com_members'); ?>" method="post" data-section-registation="password" data-section-profile="password">
 									<span class="section-edit-errors"></span>
-									<label for="password">
-										<?php echo Lang::txt('PLG_MEMBERS_PROFILE_PASSWORD_CURRENT'); ?>
-										<input type="password" name="oldpass" id="password" class="input-text" />
-									</label>
-									<label for="newpass" class="side-by-side">
-										<?php echo Lang::txt('PLG_MEMBERS_PROFILE_PASSWORD_NEW'); ?>
-										<input type="password" name="newpass" id="newpass" class="input-text" />
-									</label>
-									<label for="newpass2" class="side-by-side no-padding-right">
-										<?php echo Lang::txt('PLG_MEMBERS_PROFILE_PASSWORD_CONFIRM'); ?>
-										<input type="password" name="newpass2" id="newpass2" class="input-text" />
-									</label>
+									<?php if ($passtype == 'changelocal' || $passtype == 'changehub'): ?>
+										<div class="input-wrap">
+											<label for="password">
+												<?php echo Lang::txt('PLG_MEMBERS_PROFILE_PASSWORD_CURRENT'); ?>
+												<input type="password" name="oldpass" id="password" class="input-text" />
+											</label>
+										</div>
+									<?php endif; ?>
+									<div class="input-wrap">
+										<label for="newpass" class="side-by-side">
+											<?php echo Lang::txt('PLG_MEMBERS_PROFILE_PASSWORD_NEW'); ?>
+											<input type="password" name="newpass" id="newpass" class="input-text" />
+										</label>
+										<label for="newpass2" class="side-by-side no-padding-right">
+											<?php echo Lang::txt('PLG_MEMBERS_PROFILE_PASSWORD_CONFIRM'); ?>
+											<input type="password" name="newpass2" id="newpass2" class="input-text" />
+										</label>
+									</div>
 									<input type="hidden" name="change" value="1" />
-									<input type="submit" class="section-edit-submit" value="Save" />
-									<input type="reset" class="section-edit-cancel" value="Cancel" />
+									<input type="submit" class="section-edit-submit btn" value="<?php echo Lang::txt('PLG_MEMBERS_PROFILE_SAVE'); ?>" />
+									<input type="reset" class="section-edit-cancel btn" value="<?php echo Lang::txt('PLG_MEMBERS_PROFILE_CANCEL'); ?>" />
 									<input type="hidden" name="option" value="com_members" />
 									<input type="hidden" name="controller" value="profiles" />
 									<input type="hidden" name="id" value="<?php echo $this->profile->get('id'); ?>" />
@@ -379,6 +423,31 @@ $legacy = array(
 						</a>
 					</div>
 				</li>
+			<?php else: ?>
+				<li class="profile-password section hidden">
+					<div class="section-content">
+						<div class="key"><?php echo Lang::txt('PLG_MEMBERS_PROFILE_PASSWORD'); ?></div>
+						<div class="value">
+							<?php
+							// Determine what type of password change the user needs
+							if ($passtype == 'changelocal' || $passtype == 'changehub')
+							{
+								echo '***************';
+							}
+							else
+							{
+								// No password has been set...
+								echo Lang::txt('PLG_MEMBERS_PROFILE_PASSWORD_NOT_SET');
+							}
+							?>
+						</div>
+					</div>
+					<div class="section-edit">
+						<a href="<?php echo Route::url($this->profile->link() . '&active=account'); ?>">
+							<?php echo Lang::txt('PLG_MEMBERS_PROFILE_EDIT'); ?>
+						</a>
+					</div>
+				</li>
 			<?php endif; ?>
 		<?php endif; ?>
 
