@@ -78,7 +78,7 @@ class plgMembersUsage extends \Hubzero\Plugin\Plugin
 
 		$arr = array(
 			'html' => '',
-			'metadata' => ''
+			'metadata' => array()
 		);
 
 		// Check if our area is in the array of areas we want to return results for
